<?php

/**
 * Module Account
 */
class LCWoo_Account extends DSLC_Module {

	/**
	 * ID
	 *
	 * @var string
	 */
	var $module_id;

	/**
	 * Title
	 *
	 * @var string
	 */
	var $module_title;

	/**
	 * Icon
	 *
	 * @var string
	 */
	var $module_icon;

	/**
	 * Category
	 *
	 * @var string
	 */
	var $module_category;

	/**
	 * Construct
	 */
	function __construct() {

		$this->module_id = 'LCWoo_Account';
		$this->module_title = __( 'Account', 'lc-woo-integration' );
		$this->module_icon = 'user';
		$this->module_category = 'Woo Account';

	}

	/**
	 * Options
	 */
	function options() {
		$options = array(

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_general_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_general_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_general_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_general_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_general_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_general_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_general_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_general_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
			),

			/**
			 * Typography
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_typography_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Link - Color', 'lc-woo-integration' ),
				'id' => 'css_typography_link_color',
				'std' => '#96588a',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p a, .woo_my_account p strong',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_typography_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_typography_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Link - Font Weight', 'lc-woo-integration' ),
				'id' => 'css_typography_link_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p a, .woo_my_account p strong',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_typography_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_typography_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_typography_text_align',
				'std' => 'left',
				'type' => 'select',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
				'choices' => array(
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
					array(
						'label' => __( 'Center', 'lc-woo-integration' ),
						'value' => 'center',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Justify', 'lc-woo-integration' ),
						'value' => 'justify',
					),
				),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_typography_margin_bottom',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),

			/**
			 * Titles
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_titles_color',
				'std' => '#484c51',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account h2',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_titles_font_size',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account h2',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_titles_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account h2',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_titles_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account h2',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_titles_line_height',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account h2',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_titles_margin_bottom',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account h2',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Titles', 'lc-woo-integration' ),
			),

			// /**
			//  * Subscriptions
			//  */

			// array(
			// 	'label' => __( 'Border Color', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_border_color',
			// 	'std' => '',
			// 	'type' => 'color',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders',
			// 	'affect_on_change_rule' => 'border-color',
			// 	'section' => 'styling',
			// 	'tab' => __( 'Subscriptions', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Border Width', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_border_width',
			// 	'std' => '0',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders',
			// 	'affect_on_change_rule' => 'border-width',
			// 	'section' => 'styling',
			// 	'ext' => 'px',
			// 	'tab' => __( 'Subscriptions', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Border Radius', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_border_radius',
			// 	'std' => '0',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders',
			// 	'affect_on_change_rule' => 'border-radius',
			// 	'section' => 'styling',
			// 	'ext' => 'px',
			// 	'tab' => __( 'Subscriptions', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Borders', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_border_trbl',
			// 	'std' => 'top right bottom left',
			// 	'type' => 'checkbox',
			// 	'choices' => array(
			// 		array(
			// 			'label' => __( 'Top', 'lc-woo-integration' ),
			// 			'value' => 'top'
			// 		),
			// 		array(
			// 			'label' => __( 'Right', 'lc-woo-integration' ),
			// 			'value' => 'right'
			// 		),
			// 		array(
			// 			'label' => __( 'Bottom', 'lc-woo-integration' ),
			// 			'value' => 'bottom'
			// 		),
			// 		array(
			// 			'label' => __( 'Left', 'lc-woo-integration' ),
			// 			'value' => 'left'
			// 		),
			// 	),
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders',
			// 	'affect_on_change_rule' => 'border-style',
			// 	'section' => 'styling',
			// 	'tab' => __( 'Subscriptions', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_margin_bottom',
			// 	'std' => '30',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders',
			// 	'affect_on_change_rule' => 'margin-bottom',
			// 	'section' => 'styling',
			// 	'ext' => 'px',
			// 	'tab' => __( 'Subscriptions', 'lc-woo-integration' ),
			// ),

			// /**
			//  * Subscriptions > Title
			//  */

			// array(
			// 	'label' => __( 'Border Color', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_title_border_color',
			// 	'std' => '#e3e3e3',
			// 	'type' => 'color',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders thead tr',
			// 	'affect_on_change_rule' => 'border-color',
			// 	'section' => 'styling',
			// 	'tab' => __( 'Subscriptions > Title', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Border Width', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_title_border_width',
			// 	'std' => '2',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders thead tr',
			// 	'affect_on_change_rule' => 'border-width',
			// 	'section' => 'styling',
			// 	'ext' => 'px',
			// 	'tab' => __( 'Subscriptions > Title', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Border Radius', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_title_border_radius',
			// 	'std' => '0',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders thead tr',
			// 	'affect_on_change_rule' => 'border-radius',
			// 	'section' => 'styling',
			// 	'ext' => 'px',
			// 	'tab' => __( 'Subscriptions > Title', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Borders', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_title_border_trbl',
			// 	'std' => 'bottom',
			// 	'type' => 'checkbox',
			// 	'choices' => array(
			// 		array(
			// 			'label' => __( 'Top', 'lc-woo-integration' ),
			// 			'value' => 'top'
			// 		),
			// 		array(
			// 			'label' => __( 'Right', 'lc-woo-integration' ),
			// 			'value' => 'right'
			// 		),
			// 		array(
			// 			'label' => __( 'Bottom', 'lc-woo-integration' ),
			// 			'value' => 'bottom'
			// 		),
			// 		array(
			// 			'label' => __( 'Left', 'lc-woo-integration' ),
			// 			'value' => 'left'
			// 		),
			// 	),
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders thead tr',
			// 	'affect_on_change_rule' => 'border-style',
			// 	'section' => 'styling',
			// 	'tab' => __( 'Subscriptions > Title', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Color', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_title_color',
			// 	'std' => '#60646C',
			// 	'type' => 'color',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders thead tr th',
			// 	'affect_on_change_rule' => 'color',
			// 	'section' => 'styling',
			// 	'tab' => __( 'Subscriptions > Title', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Font Size', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_title_form_font_size',
			// 	'std' => '15',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders thead tr th',
			// 	'affect_on_change_rule' => 'font-size',
			// 	'section' => 'styling',
			// 	'ext' => 'px',
			// 	'tab' => __( 'Subscriptions > Title', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Font Weight', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_title_font_weight',
			// 	'std' => '400',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders thead tr th',
			// 	'affect_on_change_rule' => 'font-weight',
			// 	'section' => 'styling',
			// 	'ext' => '',
			// 	'min' => 100,
			// 	'max' => 900,
			// 	'increment' => 100,
			// 	'tab' => __( 'Subscriptions > Title', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Font Family', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_title_font_family',
			// 	'std' => '',
			// 	'type' => 'font',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders thead tr th',
			// 	'affect_on_change_rule' => 'font-family',
			// 	'section' => 'styling',
			// 	'tab' => __( 'Subscriptions > Title', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Line Height', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_title_line_height',
			// 	'std' => '22',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders thead tr th',
			// 	'affect_on_change_rule' => 'line-height',
			// 	'section' => 'styling',
			// 	'ext' => 'px',
			// 	'tab' => __( 'Subscriptions > Title', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Text Transform', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_title_text_transform',
			// 	'std' => 'uppercase',
			// 	'type' => 'select',
			// 	'choices' => array(
			// 		array(
			// 			'label' => __( 'None', 'lc-woo-integration' ),
			// 			'value' => 'none'
			// 		),
			// 		array(
			// 			'label' => __( 'Capitalize', 'lc-woo-integration' ),
			// 			'value' => 'capitalize'
			// 		),
			// 		array(
			// 			'label' => __( 'Uppercase', 'lc-woo-integration' ),
			// 			'value' => 'uppercase'
			// 		),
			// 		array(
			// 			'label' => __( 'Lowercase', 'lc-woo-integration' ),
			// 			'value' => 'lowercase'
			// 		),
			// 	),
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders thead tr th',
			// 	'affect_on_change_rule' => 'text-transform',
			// 	'section' => 'styling',
			// 	'tab' => __( 'Subscriptions > Title', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_title_padding_vertical',
			// 	'std' => '10',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders thead tr th',
			// 	'affect_on_change_rule' => 'padding-top,padding-bottom',
			// 	'section' => 'styling',
			// 	'ext' => 'px',
			// 	'tab' => __( 'Subscriptions > Title', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_title_padding_horizontal',
			// 	'std' => '22',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders thead tr th',
			// 	'affect_on_change_rule' => 'padding-left,padding-right',
			// 	'section' => 'styling',
			// 	'ext' => 'px',
			// 	'tab' => __( 'Subscriptions > Title', 'lc-woo-integration' ),
			// ),

			// /**
			//  * Subscriptions > Order
			//  */

			// array(
			// 	'label' => __( 'BG Color', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_order_bg_color',
			// 	'std' => '#f6f6f6',
			// 	'type' => 'color',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders tbody tr',
			// 	'affect_on_change_rule' => 'background-color',
			// 	'section' => 'styling',
			// 	'tab' => __( 'Subscriptions > Order', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Border Color', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_order_border_color',
			// 	'std' => '#EFEFEF',
			// 	'type' => 'color',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders tbody tr',
			// 	'affect_on_change_rule' => 'border-color',
			// 	'section' => 'styling',
			// 	'tab' => __( 'Subscriptions > Order', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Border Width', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_order_border_width',
			// 	'std' => '1',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders tbody tr',
			// 	'affect_on_change_rule' => 'border-width',
			// 	'section' => 'styling',
			// 	'ext' => 'px',
			// 	'tab' => __( 'Subscriptions > Order', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Border Radius', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_order_border_radius',
			// 	'std' => '0',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders tbody tr',
			// 	'affect_on_change_rule' => 'border-radius',
			// 	'section' => 'styling',
			// 	'ext' => 'px',
			// 	'tab' => __( 'Subscriptions > Order', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Borders', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_order_border_trbl',
			// 	'std' => 'bottom',
			// 	'type' => 'checkbox',
			// 	'choices' => array(
			// 		array(
			// 			'label' => __( 'Top', 'lc-woo-integration' ),
			// 			'value' => 'top'
			// 		),
			// 		array(
			// 			'label' => __( 'Right', 'lc-woo-integration' ),
			// 			'value' => 'right'
			// 		),
			// 		array(
			// 			'label' => __( 'Bottom', 'lc-woo-integration' ),
			// 			'value' => 'bottom'
			// 		),
			// 		array(
			// 			'label' => __( 'Left', 'lc-woo-integration' ),
			// 			'value' => 'left'
			// 		),
			// 	),
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders tbody tr',
			// 	'affect_on_change_rule' => 'border-style',
			// 	'section' => 'styling',
			// 	'tab' => __( 'Subscriptions > Order', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Color', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_order_color',
			// 	'std' => '#60646C',
			// 	'type' => 'color',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders tbody tr td',
			// 	'affect_on_change_rule' => 'color',
			// 	'section' => 'styling',
			// 	'tab' => __( 'Subscriptions > Order', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Link - Color', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_order_link_color',
			// 	'std' => '#a16b97',
			// 	'type' => 'color',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders tbody tr td a',
			// 	'affect_on_change_rule' => 'color',
			// 	'section' => 'styling',
			// 	'tab' => __( 'Subscriptions > Order', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Font Size', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_order_form_font_size',
			// 	'std' => '15',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders tbody tr td',
			// 	'affect_on_change_rule' => 'font-size',
			// 	'section' => 'styling',
			// 	'ext' => 'px',
			// 	'tab' => __( 'Subscriptions > Order', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Font Weight', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_order_font_weight',
			// 	'std' => '300',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders tbody tr td',
			// 	'affect_on_change_rule' => 'font-weight',
			// 	'section' => 'styling',
			// 	'ext' => '',
			// 	'min' => 100,
			// 	'max' => 900,
			// 	'increment' => 100,
			// 	'tab' => __( 'Subscriptions > Order', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Link - Font Weight', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_order_link_font_weight',
			// 	'std' => '400',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders tbody tr td a',
			// 	'affect_on_change_rule' => 'font-weight',
			// 	'section' => 'styling',
			// 	'ext' => '',
			// 	'min' => 100,
			// 	'max' => 900,
			// 	'increment' => 100,
			// 	'tab' => __( 'Subscriptions > Order', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Font Family', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_order_font_family',
			// 	'std' => '',
			// 	'type' => 'font',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders tbody tr td',
			// 	'affect_on_change_rule' => 'font-family',
			// 	'section' => 'styling',
			// 	'tab' => __( 'Subscriptions > Order', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Line Height', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_order_line_height',
			// 	'std' => '22',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders tbody tr td',
			// 	'affect_on_change_rule' => 'line-height',
			// 	'section' => 'styling',
			// 	'ext' => 'px',
			// 	'tab' => __( 'Subscriptions > Order', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_order_padding_vertical',
			// 	'std' => '10',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders tbody tr td',
			// 	'affect_on_change_rule' => 'padding-top,padding-bottom',
			// 	'section' => 'styling',
			// 	'ext' => 'px',
			// 	'tab' => __( 'Subscriptions > Order', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_order_padding_horizontal',
			// 	'std' => '43',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table.my_account_orders tbody tr td',
			// 	'affect_on_change_rule' => 'padding-left,padding-right',
			// 	'section' => 'styling',
			// 	'ext' => 'px',
			// 	'tab' => __( 'Subscriptions > Order', 'lc-woo-integration' ),
			// ),

			// /**
			//  * Subscriptions > Button
			//  */

			// array(
			// 	'label' => __( 'BG Color', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_button_bg_color',
			// 	'std' => '#60646c',
			// 	'type' => 'color',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button',
			// 	'affect_on_change_rule' => 'background-color',
			// 	'section' => 'styling',
			// 	'tab' => __( 'Subscriptions > Button', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'BG:Hover Color', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_button_bg_hover_color',
			// 	'std' => '#7E8085',
			// 	'type' => 'color',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button:hover',
			// 	'affect_on_change_rule' => 'background-color',
			// 	'section' => 'styling',
			// 	'tab' => __( 'Subscriptions > Button', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Border Color', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_button_border_color',
			// 	'std' => '',
			// 	'type' => 'color',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button',
			// 	'affect_on_change_rule' => 'border-color',
			// 	'section' => 'styling',
			// 	'tab' => __( 'Subscriptions > Button', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Border Width', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_button_border_width',
			// 	'std' => '0',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button',
			// 	'affect_on_change_rule' => 'border-width',
			// 	'section' => 'styling',
			// 	'ext' => 'px',
			// 	'tab' => __( 'Subscriptions > Button', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Border Radius', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_button_border_radius',
			// 	'std' => '0',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button',
			// 	'affect_on_change_rule' => 'border-radius',
			// 	'section' => 'styling',
			// 	'ext' => 'px',
			// 	'tab' => __( 'Subscriptions > Button', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Borders', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_button_border_trbl',
			// 	'std' => 'top right bottom left',
			// 	'type' => 'checkbox',
			// 	'choices' => array(
			// 		array(
			// 			'label' => __( 'Top', 'lc-woo-integration' ),
			// 			'value' => 'top'
			// 		),
			// 		array(
			// 			'label' => __( 'Right', 'lc-woo-integration' ),
			// 			'value' => 'right'
			// 		),
			// 		array(
			// 			'label' => __( 'Bottom', 'lc-woo-integration' ),
			// 			'value' => 'bottom'
			// 		),
			// 		array(
			// 			'label' => __( 'Left', 'lc-woo-integration' ),
			// 			'value' => 'left'
			// 		),
			// 	),
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button',
			// 	'affect_on_change_rule' => 'border-style',
			// 	'section' => 'styling',
			// 	'tab' => __( 'Subscriptions > Button', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Color', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_button_color',
			// 	'std' => '#ffffff',
			// 	'type' => 'color',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button',
			// 	'affect_on_change_rule' => 'color',
			// 	'section' => 'styling',
			// 	'tab' => __( 'Subscriptions > Button', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Font Size', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_button_form_font_size',
			// 	'std' => '14',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button',
			// 	'affect_on_change_rule' => 'font-size',
			// 	'section' => 'styling',
			// 	'ext' => 'px',
			// 	'tab' => __( 'Subscriptions > Button', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Font Weight', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_button_font_weight',
			// 	'std' => '300',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button',
			// 	'affect_on_change_rule' => 'font-weight',
			// 	'section' => 'styling',
			// 	'ext' => '',
			// 	'min' => 100,
			// 	'max' => 900,
			// 	'increment' => 100,
			// 	'tab' => __( 'Subscriptions > Button', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Font Family', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_button_font_family',
			// 	'std' => '',
			// 	'type' => 'font',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button',
			// 	'affect_on_change_rule' => 'font-family',
			// 	'section' => 'styling',
			// 	'tab' => __( 'Subscriptions > Button', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Line Height', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_button_line_height',
			// 	'std' => '20',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button',
			// 	'affect_on_change_rule' => 'line-height',
			// 	'section' => 'styling',
			// 	'ext' => 'px',
			// 	'tab' => __( 'Subscriptions > Button', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_button_padding_vertical',
			// 	'std' => '8',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button',
			// 	'affect_on_change_rule' => 'padding-top,padding-bottom',
			// 	'section' => 'styling',
			// 	'ext' => 'px',
			// 	'tab' => __( 'Subscriptions > Button', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_button_padding_horizontal',
			// 	'std' => '12',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button',
			// 	'affect_on_change_rule' => 'padding-left,padding-right',
			// 	'section' => 'styling',
			// 	'ext' => 'px',
			// 	'tab' => __( 'Subscriptions > Button', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
			// 	'id' => 'css_subscriptions_button_margin_bottom',
			// 	'std' => '0',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button',
			// 	'affect_on_change_rule' => 'margin-bottom',
			// 	'section' => 'styling',
			// 	'ext' => 'px',
			// 	'tab' => __( 'Subscriptions > Button', 'lc-woo-integration' ),
			// ),

			/**
			 * Available Downloads
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_available_downloads_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads li',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Available Downloads', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_available_downloads_border_color',
				'std' => '#EFEFEF',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads li',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Available Downloads', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_available_downloads_border_width',
				'std' => '1',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads li',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Available Downloads', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_available_downloads_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads li',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Available Downloads', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_available_downloads_border_trbl',
				'std' => 'bottom',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads li',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Available Downloads', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_available_downloads_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads li',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Available Downloads', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Link - Color', 'lc-woo-integration' ),
				'id' => 'css_available_downloads_link_color',
				'std' => '#a16b97',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads li a',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Available Downloads', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_available_downloads_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads li',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Available Downloads', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_available_downloads_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads li',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Available Downloads', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Link - Font Weight', 'lc-woo-integration' ),
				'id' => 'css_available_downloads_link_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads li a',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Available Downloads', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_available_downloads_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads li',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Available Downloads', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_available_downloads_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads li',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Available Downloads', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_available_downloads_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads li',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Available Downloads', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_available_downloads_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads li',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Available Downloads', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_available_downloads_margin_bottom',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Available Downloads', 'lc-woo-integration' ),
			),

			/**
			 * Orders
			 */

			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_orders_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Orders', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_orders_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Orders', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_orders_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Orders', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_orders_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Orders', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_orders_margin_bottom',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Orders', 'lc-woo-integration' ),
			),

			/**
			 * Orders > Title
			 */

			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_orders_title_border_color',
				'std' => '#e3e3e3',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders thead tr',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Orders > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_orders_title_border_width',
				'std' => '2',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders thead tr',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Orders > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_orders_title_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders thead tr',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Orders > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_orders_title_border_trbl',
				'std' => 'bottom',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders thead tr',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Orders > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_orders_title_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders thead th',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Orders > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_orders_title_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders thead th',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Orders > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_orders_title_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders thead th',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Orders > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_orders_title_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders thead th',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Orders > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_orders_title_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders thead th',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Orders > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Text Transform', 'lc-woo-integration' ),
				'id' => 'css_orders_title_text_transform',
				'std' => 'uppercase',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'None', 'lc-woo-integration' ),
						'value' => 'none',
					),
					array(
						'label' => __( 'Capitalize', 'lc-woo-integration' ),
						'value' => 'capitalize',
					),
					array(
						'label' => __( 'Uppercase', 'lc-woo-integration' ),
						'value' => 'uppercase',
					),
					array(
						'label' => __( 'Lowercase', 'lc-woo-integration' ),
						'value' => 'lowercase',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders thead th',
				'affect_on_change_rule' => 'text-transform',
				'section' => 'styling',
				'tab' => __( 'Orders > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_orders_title_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders thead th',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Orders > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_orders_title_padding_horizontal',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders thead th',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Orders > Title', 'lc-woo-integration' ),
			),

			/**
			 * Orders > Order
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_orders_order_bg_color',
				'std' => '#f6f6f6',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody tr',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Orders > Order', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_orders_order_border_color',
				'std' => '#EFEFEF',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody tr',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Orders > Order', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_orders_order_border_width',
				'std' => '1',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody tr',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Orders > Order', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_orders_order_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody tr',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Orders > Order', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_orders_order_border_trbl',
				'std' => 'bottom',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody tr',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Orders > Order', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_orders_order_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Orders > Order', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Link - Color', 'lc-woo-integration' ),
				'id' => 'css_orders_order_link_color',
				'std' => '#a16b97',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Orders > Order', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_orders_order_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Orders > Order', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_orders_order_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Orders > Order', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Link - Font Weight', 'lc-woo-integration' ),
				'id' => 'css_orders_order_link_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Orders > Order', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_orders_order_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Orders > Order', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_orders_order_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Orders > Order', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_orders_order_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Orders > Order', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_orders_order_padding_horizontal',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Orders > Order', 'lc-woo-integration' ),
			),

			/**
			 * Orders > Button
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_orders_button_bg_color',
				'std' => '#60646c',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Orders > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG:Hover Color', 'lc-woo-integration' ),
				'id' => 'css_orders_button_bg_hover_color',
				'std' => '#7E8085',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button:hover',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Orders > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_orders_button_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Orders > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_orders_button_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Orders > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_orders_button_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Orders > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_orders_button_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Orders > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_orders_button_color',
				'std' => '#ffffff',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Orders > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_orders_button_form_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Orders > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_orders_button_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Orders > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_orders_button_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Orders > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_orders_button_line_height',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Orders > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_orders_button_padding_vertical',
				'std' => '8',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Orders > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_orders_button_padding_horizontal',
				'std' => '12',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Orders > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_orders_button_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Orders > Button', 'lc-woo-integration' ),
			),

			/**
			 * Addresses
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_addresses_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p.myaccount_address',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Addresses', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_addresses_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p.myaccount_address',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Addresses', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_addresses_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p.myaccount_address',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_addresses_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p.myaccount_address',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_addresses_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p.myaccount_address',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Addresses', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_addresses_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p.myaccount_address',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Addresses', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_addresses_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p.myaccount_address',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_addresses_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p.myaccount_address',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Addresses', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_addresses_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p.myaccount_address',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Addresses', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_addresses_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p.myaccount_address',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_addresses_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p.myaccount_address',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_addresses_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p.myaccount_address',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_addresses_margin_bottom',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p.myaccount_address',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses', 'lc-woo-integration' ),
			),

			/**
			 * Addresses > Billing and Shipping
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .address',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Addresses > Billing and Shipping', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .address',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Addresses > Billing and Shipping', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .address',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses > Billing and Shipping', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .address',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses > Billing and Shipping', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .address',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Addresses > Billing and Shipping', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .address',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses > Billing and Shipping', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .address',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses > Billing and Shipping', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_margin_bottom',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .address',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses > Billing and Shipping', 'lc-woo-integration' ),
			),

			/**
			 * Addresses > Billing and Shipping > Title
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_title_color',
				'std' => '#484c51',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .addresses h3',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Addresses > Billing and Shipping > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Link - Color', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_title_link_color',
				'std' => '#96588a',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account header a',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Addresses > Billing and Shipping > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_title_font_size',
				'std' => '21',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .addresses h3',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses > Billing and Shipping > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_title_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .addresses h3',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Addresses > Billing and Shipping > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Link - Font Weight', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_title_link_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account header a',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Addresses > Billing and Shipping > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_title_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .addresses h3',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Addresses > Billing and Shipping > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_title_line_height',
				'std' => '27',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .addresses h3',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses > Billing and Shipping > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_title_margin_bottom',
				'std' => '18',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .addresses h3',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses > Billing and Shipping > Title', 'lc-woo-integration' ),
			),

			/**
			 * Addresses > Billing and Shipping > Address
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_address_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .addresses address',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Addresses > Billing and Shipping > Address', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_address_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .addresses address',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses > Billing and Shipping > Address', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_address_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .addresses address',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Addresses > Billing and Shipping > Address', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_address_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .addresses address',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Addresses > Billing and Shipping > Address', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_address_line_height',
				'std' => '23',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .addresses address',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses > Billing and Shipping > Address', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Style', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_address_font_style',
				'std' => 'italic',
				'type' => 'select',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .addresses address',
				'affect_on_change_rule' => 'font-style',
				'section' => 'styling',
				'tab' => __( 'Addresses > Billing and Shipping > Address', 'lc-woo-integration' ),
				'choices' => array(
					array(
						'label' => __( 'Normal', 'lc-woo-integration' ),
						'value' => 'normal',
					),
					array(
						'label' => __( 'Italic', 'lc-woo-integration' ),
						'value' => 'italic',
					),
				),
			),

			/**
			 * Responsive Tablet
			 */

			array(
				'label' => __( 'Responsive', 'lc-woo-integration' ),
				'id' => 'css_res_t',
				'std' => 'disabled',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Disabled', 'lc-woo-integration' ),
						'value' => 'disabled',
					),
					array(
						'label' => __( 'Enabled', 'lc-woo-integration' ),
						'value' => 'enabled',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_general_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_general_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_general_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_typography_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_typography_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_typography_margin_bottom',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Titles - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_titles_font_size',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account h2',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Titles - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_titles_line_height',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account h2',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Titles - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_titles_margin_bottom',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account h2',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			// array(
			// 	'label' => __( 'Subscriptions - Margin Bottom', 'lc-woo-integration' ),
			// 	'id' => 'css_res_t_subscriptions_margin_bottom',
			// 	'std' => '30',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table',
			// 	'affect_on_change_rule' => 'margin-bottom',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'tablet', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Subscriptions > Title - Font Size', 'lc-woo-integration' ),
			// 	'id' => 'css_res_t_subscriptions_title_form_font_size',
			// 	'std' => '15',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table thead tr th',
			// 	'affect_on_change_rule' => 'font-size',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'tablet', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Subscriptions > Title - Line Height', 'lc-woo-integration' ),
			// 	'id' => 'css_res_t_subscriptions_title_line_height',
			// 	'std' => '22',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table thead tr th',
			// 	'affect_on_change_rule' => 'line-height',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'tablet', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Subscriptions > Title - Padding Vertical', 'lc-woo-integration' ),
			// 	'id' => 'css_res_t_subscriptions_title_padding_vertical',
			// 	'std' => '10',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table thead tr th',
			// 	'affect_on_change_rule' => 'padding-top,padding-bottom',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'tablet', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Subscriptions > Title - Padding Horizontal', 'lc-woo-integration' ),
			// 	'id' => 'css_res_t_subscriptions_title_padding_horizontal',
			// 	'std' => '22',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table thead tr th',
			// 	'affect_on_change_rule' => 'padding-left,padding-right',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'tablet', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Subscriptions > Order - Font Size', 'lc-woo-integration' ),
			// 	'id' => 'css_res_t_subscriptions_order_form_font_size',
			// 	'std' => '15',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td',
			// 	'affect_on_change_rule' => 'font-size',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'tablet', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Subscriptions > Order - Line Height', 'lc-woo-integration' ),
			// 	'id' => 'css_res_t_subscriptions_order_line_height',
			// 	'std' => '22',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td',
			// 	'affect_on_change_rule' => 'line-height',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'tablet', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Subscriptions > Order - Padding Vertical', 'lc-woo-integration' ),
			// 	'id' => 'css_res_t_subscriptions_order_padding_vertical',
			// 	'std' => '10',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td',
			// 	'affect_on_change_rule' => 'padding-top,padding-bottom',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'tablet', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Subscriptions > Order - Padding Horizontal', 'lc-woo-integration' ),
			// 	'id' => 'css_res_t_subscriptions_order_padding_horizontal',
			// 	'std' => '22',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td',
			// 	'affect_on_change_rule' => 'padding-left,padding-right',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'tablet', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Subscriptions > Button - Font Size', 'lc-woo-integration' ),
			// 	'id' => 'css_res_t_subscriptions_button_form_font_size',
			// 	'std' => '14',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button',
			// 	'affect_on_change_rule' => 'font-size',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'tablet', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Subscriptions > Button - Line Height', 'lc-woo-integration' ),
			// 	'id' => 'css_res_t_subscriptions_button_line_height',
			// 	'std' => '20',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button',
			// 	'affect_on_change_rule' => 'line-height',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'tablet', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Subscriptions > Button - Padding Vertical', 'lc-woo-integration' ),
			// 	'id' => 'css_res_t_subscriptions_button_padding_vertical',
			// 	'std' => '8',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button',
			// 	'affect_on_change_rule' => 'padding-top,padding-bottom',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'tablet', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Subscriptions > Button - Padding Horizontal', 'lc-woo-integration' ),
			// 	'id' => 'css_res_t_subscriptions_button_padding_horizontal',
			// 	'std' => '12',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button',
			// 	'affect_on_change_rule' => 'padding-left,padding-right',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'tablet', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Subscriptions > Button - Margin Bottom', 'lc-woo-integration' ),
			// 	'id' => 'css_res_t_subscriptions_button_margin_bottom',
			// 	'std' => '0',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button',
			// 	'affect_on_change_rule' => 'margin-bottom',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'tablet', 'lc-woo-integration' ),
			// ),
			array(
				'label' => __( 'Available Downloads - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_available_downloads_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads li',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Available Downloads - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_available_downloads_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads li',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Available Downloads - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_available_downloads_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads li',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Available Downloads - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_available_downloads_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads li',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Available Downloads - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_available_downloads_margin_bottom',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_orders_margin_bottom',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_orders_title_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders thead th',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_orders_title_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders thead th',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders > Title - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_orders_title_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders thead th',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders > Title - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_orders_title_padding_horizontal',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders thead th',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders > Order - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_orders_order_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders > Order - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_orders_order_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders > Order - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_orders_order_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders > Order - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_orders_order_padding_horizontal',
				'std' => '38',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders > Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_orders_button_form_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders > Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_orders_button_line_height',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders > Button - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_orders_button_padding_vertical',
				'std' => '8',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders > Button - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_orders_button_padding_horizontal',
				'std' => '12',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders > Button - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_orders_button_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_addresses_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p.myaccount_address',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_addresses_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p.myaccount_address',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_addresses_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p.myaccount_address',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_addresses_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p.myaccount_address',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_addresses_margin_bottom',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p.myaccount_address',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_addresses_billing_and_shipping_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .address',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_addresses_billing_and_shipping_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .address',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_addresses_billing_and_shipping_margin_bottom',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .address',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_addresses_billing_and_shipping_title_font_size',
				'std' => '21',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .addresses h3',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_addresses_billing_and_shipping_title_line_height',
				'std' => '27',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .addresses h3',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping > Title - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_addresses_billing_and_shipping_title_margin_bottom',
				'std' => '18',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .addresses h3',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping > Address - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_addresses_billing_and_shipping_address_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .addresses address',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping > Address - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_addresses_billing_and_shipping_address_line_height',
				'std' => '23',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .addresses address',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),

			/**
			 * Responsive Phone
			 */

			array(
				'label' => __( 'Responsive', 'lc-woo-integration' ),
				'id' => 'css_res_p',
				'std' => 'disabled',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Disabled', 'lc-woo-integration' ),
						'value' => 'disabled',
					),
					array(
						'label' => __( 'Enabled', 'lc-woo-integration' ),
						'value' => 'enabled',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_general_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_general_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_general_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_typography_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_typography_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_typography_margin_bottom',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Titles - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_titles_font_size',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account h2',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Titles - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_titles_line_height',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account h2',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Titles - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_titles_margin_bottom',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account h2',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			// array(
			// 	'label' => __( 'Subscriptions - Margin Bottom', 'lc-woo-integration' ),
			// 	'id' => 'css_res_p_subscriptions_margin_bottom',
			// 	'std' => '30',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table',
			// 	'affect_on_change_rule' => 'margin-bottom',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'phone', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Subscriptions > Order - Font Size', 'lc-woo-integration' ),
			// 	'id' => 'css_res_p_subscriptions_order_form_font_size',
			// 	'std' => '15',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td',
			// 	'affect_on_change_rule' => 'font-size',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'phone', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Subscriptions > Order - Line Height', 'lc-woo-integration' ),
			// 	'id' => 'css_res_p_subscriptions_order_line_height',
			// 	'std' => '22',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td',
			// 	'affect_on_change_rule' => 'line-height',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'phone', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Subscriptions > Order - Padding Vertical', 'lc-woo-integration' ),
			// 	'id' => 'css_res_p_subscriptions_order_padding_vertical',
			// 	'std' => '10',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td',
			// 	'affect_on_change_rule' => 'padding-top,padding-bottom',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'phone', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Subscriptions > Order - Padding Horizontal', 'lc-woo-integration' ),
			// 	'id' => 'css_res_p_subscriptions_order_padding_horizontal',
			// 	'std' => '20',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td',
			// 	'affect_on_change_rule' => 'padding-left,padding-right',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'phone', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Subscriptions > Button - Font Size', 'lc-woo-integration' ),
			// 	'id' => 'css_res_p_subscriptions_button_form_font_size',
			// 	'std' => '14',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button',
			// 	'affect_on_change_rule' => 'font-size',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'phone', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Subscriptions > Button - Line Height', 'lc-woo-integration' ),
			// 	'id' => 'css_res_p_subscriptions_button_line_height',
			// 	'std' => '20',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button',
			// 	'affect_on_change_rule' => 'line-height',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'phone', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Subscriptions > Button - Padding Vertical', 'lc-woo-integration' ),
			// 	'id' => 'css_res_p_subscriptions_button_padding_vertical',
			// 	'std' => '8',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button',
			// 	'affect_on_change_rule' => 'padding-top,padding-bottom',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'phone', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Subscriptions > Button - Padding Horizontal', 'lc-woo-integration' ),
			// 	'id' => 'css_res_p_subscriptions_button_padding_horizontal',
			// 	'std' => '12',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button',
			// 	'affect_on_change_rule' => 'padding-left,padding-right',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'phone', 'lc-woo-integration' ),
			// ),
			// array(
			// 	'label' => __( 'Subscriptions > Button - Margin Bottom', 'lc-woo-integration' ),
			// 	'id' => 'css_res_p_subscriptions_button_margin_bottom',
			// 	'std' => '5',
			// 	'type' => 'slider',
			// 	'refresh_on_change' => false,
			// 	'affect_on_change_el' => '.woocommerce_account_subscriptions table tbody tr td a.button',
			// 	'affect_on_change_rule' => 'margin-bottom',
			// 	'section' => 'responsive',
			// 	'ext' => 'px',
			// 	'tab' => __( 'phone', 'lc-woo-integration' ),
			// ),
			array(
				'label' => __( 'Available Downloads - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_available_downloads_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads li',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Available Downloads - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_available_downloads_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads li',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Available Downloads - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_available_downloads_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads li',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Available Downloads - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_available_downloads_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads li',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Available Downloads - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_available_downloads_margin_bottom',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .digital-downloads',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_orders_margin_bottom',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders > Order - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_orders_order_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders > Order - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_orders_order_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders > Order - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_orders_order_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders > Order - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_orders_order_padding_horizontal',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders > Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_orders_button_form_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders > Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_orders_button_line_height',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders > Button - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_orders_button_padding_vertical',
				'std' => '8',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders > Button - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_orders_button_padding_horizontal',
				'std' => '12',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Orders > Button - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_orders_button_margin_bottom',
				'std' => '5',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'table.my_account_orders tbody td a.button',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_addresses_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p.myaccount_address',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_addresses_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p.myaccount_address',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_addresses_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p.myaccount_address',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_addresses_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p.myaccount_address',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_addresses_margin_bottom',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account p.myaccount_address',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_addresses_billing_and_shipping_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .address',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_addresses_billing_and_shipping_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .address',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_addresses_billing_and_shipping_margin_bottom',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .address',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_addresses_billing_and_shipping_title_font_size',
				'std' => '21',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .addresses h3',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_addresses_billing_and_shipping_title_line_height',
				'std' => '27',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .addresses h3',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping > Title - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_addresses_billing_and_shipping_title_margin_bottom',
				'std' => '18',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .addresses h3',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping > Address - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_addresses_billing_and_shipping_address_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .addresses address',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping > Address - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_addresses_billing_and_shipping_address_line_height',
				'std' => '23',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo_my_account .addresses address',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
		);

		$options = array_merge( $options, $this->shared_options( 'animation_options' ) );
		$options = array_merge( $options, $this->presets_options() );

		return apply_filters( 'dslc_module_options', $options, $this->module_id );
	}

	/**
	 * Output
	 *
	 * @param array $options
	 */
	function output( $options ) {

		$this->module_start( $options );

		?>
			<div class='woo_my_account'><?php echo do_shortcode( '[woocommerce_my_account]' ); ?></div>
		<?php

		$this->module_end( $options );
	}
}

add_action('dslc_hook_register_modules',
	create_function( '', 'return dslc_register_module( "LCWoo_Account" );' )
);
