<?php

/**
 * Module Edit Account
 */
class LCWoo_edit_account extends DSLC_Module {

	/**
	 * ID
	 *
	 * @var string
	 */
	var $module_id;

	/**
	 * Title
	 *
	 * @var string
	 */
	var $module_title;

	/**
	 * Icon
	 *
	 * @var string
	 */
	var $module_icon;

	/**
	 * Category
	 *
	 * @var string
	 */
	var $module_category;

	/**
	 * Construct
	 */
	function __construct() {

		$this->module_id = 'LCWoo_edit_account';
		$this->module_title = __( 'Edit Account', 'lc-woo-integration' );
		$this->module_icon = 'user-plus';
		$this->module_category = 'Woo Account';

	}

	/**
	 * Options
	 */
	function options() {
		$options = array(

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_general_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_general_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_general_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_general_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_general_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_general_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_general_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_general_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
			),

			/**
			 * Typography
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_typography_link_color',
				'std' => '#60646c',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account legend',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_typography_form_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account legend',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_typography_link_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account legend',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_typography_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account legend',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_typography_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account legend',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_typography_margin_bottom',
				'std' => '4',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account legend',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),

			/**
			 * Label
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_label_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account label',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Required - Color', 'lc-woo-integration' ),
				'id' => 'css_required_label_color',
				'std' => '#FB0000',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account label span.required',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_label_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account label',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_label_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account label',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_label_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account label',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_label_line_height',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account label',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_label_margin_bottom',
				'std' => '2',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account label',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Label', 'lc-woo-integration' ),
			),

			/**
			 * Input
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_inputs_bg_color',
				'std' => '#EFEFEF',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=text], .edit-account input[type=password], .edit-account input[type=email]',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_inputs_color',
				'std' => '#484B51',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=text], .edit-account input[type=password], .edit-account input[type=email]',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_inputs_border_color',
				'std' => '#E4E4E4',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=text], .edit-account input[type=password], .edit-account input[type=email]',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_inputs_border_width',
				'std' => '1',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=text], .edit-account input[type=password], .edit-account input[type=email]',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_inputs_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=text], .edit-account input[type=password], .edit-account input[type=email]',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_inputs_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=text], .edit-account input[type=password], .edit-account input[type=email]',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_inputs_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=text], .edit-account input[type=password], .edit-account input[type=email]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'tab' => __( 'Input', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_inputs_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=text], .edit-account input[type=password], .edit-account input[type=email]',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'tab' => __( 'Input', 'lc-woo-integration' ),
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_inputs_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=text], .edit-account input[type=password], .edit-account input[type=email]',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_inputs_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=text], .edit-account input[type=password], .edit-account input[type=email]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'tab' => __( 'Input', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_inputs_margin_bottom',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account p',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_inputs_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=text], .edit-account input[type=password], .edit-account input[type=email]',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_inputs_padding_horizontal',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=text], .edit-account input[type=password], .edit-account input[type=email]',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Input', 'lc-woo-integration' ),
			),

			/**
			 * Button
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_button_bg_color',
				'std' => '#60646c',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG:Hover Color', 'lc-woo-integration' ),
				'id' => 'css_button_bg_hover_color',
				'std' => '#7E8085',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]:hover',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_button_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_button_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_button_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_button_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_button_color',
				'std' => '#ffffff',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_button_form_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_button_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_button_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_button_line_height',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_button_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_button_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_button_margin_bottom',
				'std' => '6',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),

			/**
			 * Error
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_error_bg_color',
				'std' => '#E2401C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account .woocommerce-error li',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_error_border_color',
				'std' => '#C03617',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account .woocommerce-error li',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_error_border_width',
				'std' => '9',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account .woocommerce-error li',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_error_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account .woocommerce-error li',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_error_border_trbl',
				'std' => 'left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account .woocommerce-error li',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_error_color',
				'std' => '#ffffff',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account .woocommerce-error li',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_error_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account .woocommerce-error li',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'tab' => __( 'Error', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_error_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account .woocommerce-error li',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'tab' => __( 'Error', 'lc-woo-integration' ),
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_error_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account .woocommerce-error li',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_error_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account .woocommerce-error li',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'tab' => __( 'Error', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_error_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account .woocommerce-error li',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_error_padding_horizontal',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account .woocommerce-error li',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_error_margin_bottom',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account .woocommerce-error li',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Error', 'lc-woo-integration' ),
			),

			/**
			 * Responsive Tablet
			 */

			array(
				'label' => __( 'Responsive', 'lc-woo-integration' ),
				'id' => 'css_res_t',
				'std' => 'disabled',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Disabled', 'lc-woo-integration' ),
						'value' => 'disabled',
					),
					array(
						'label' => __( 'Enabled', 'lc-woo-integration' ),
						'value' => 'enabled',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_general_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_general_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_general_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_typography_form_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account legend',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_typography_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account legend',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Label - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_label_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account label',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Label - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_label_line_height',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account label',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Label - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_label_margin_bottom',
				'std' => '2',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account label',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Input - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_inputs_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=text], .edit-account input[type=password], .edit-account input[type=email]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Input - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_inputs_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=text], .edit-account input[type=password], .edit-account input[type=email]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Input - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_inputs_margin_bottom',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account p',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Input - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_inputs_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=text], .edit-account input[type=password], .edit-account input[type=email]',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Input - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_inputs_padding_horizontal',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=text], .edit-account input[type=password], .edit-account input[type=email]',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_button_form_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_button_line_height',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_button_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_button_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_button_margin_bottom',
				'std' => '6',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Error - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_error_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account .woocommerce-error li',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Error - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_error_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account .woocommerce-error li',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Error - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_error_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account .woocommerce-error li',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Error - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_error_padding_horizontal',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account .woocommerce-error li',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Error - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_error_margin_bottom',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account .woocommerce-error li',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),

			/**
			 * Responsive Phone
			 */

			array(
				'label' => __( 'Responsive', 'lc-woo-integration' ),
				'id' => 'css_res_p',
				'std' => 'disabled',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Disabled', 'lc-woo-integration' ),
						'value' => 'disabled',
					),
					array(
						'label' => __( 'Enabled', 'lc-woo-integration' ),
						'value' => 'enabled',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_general_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_general_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_general_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_typography_form_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account legend',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_typography_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account legend',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Label - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_label_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account label',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Label - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_label_line_height',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account label',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Label - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_label_margin_bottom',
				'std' => '2',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account label',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Input - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_inputs_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=text], .edit-account input[type=password], .edit-account input[type=email]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Input - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_inputs_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=text], .edit-account input[type=password], .edit-account input[type=email]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Input - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_inputs_margin_bottom',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account p',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Input - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_inputs_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=text], .edit-account input[type=password], .edit-account input[type=email]',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Input - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_inputs_padding_horizontal',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=text], .edit-account input[type=password], .edit-account input[type=email]',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_button_form_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_button_line_height',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_button_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_button_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_button_margin_bottom',
				'std' => '6',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account input[type=submit]',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Error - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_error_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account .woocommerce-error li',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Error - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_error_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account .woocommerce-error li',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Error - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_error_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account .woocommerce-error li',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Error - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_error_padding_horizontal',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account .woocommerce-error li',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Error - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_error_margin_bottom',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.edit-account .woocommerce-error li',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),

		);

		$options = array_merge( $options, $this->shared_options( 'animation_options' ) );
		$options = array_merge( $options, $this->presets_options() );

		return apply_filters( 'dslc_module_options', $options, $this->module_id );
	}

	/**
	 * Output
	 *
	 * @param array $options
	 */
	function output( $options ) {

		$this->module_start( $options );

		global $dslc_active;

		if ( 'dslc_templates' === get_post_type() || $dslc_active ) {
		?>
			<div class="edit-account">
				<ul class="woocommerce-error">
						<li><strong>Label</strong> is a required field.</li>
					</ul>
				<form action="" method="post">
					<p class="form-row form-row-first">
						<label for="account_first_name">First name <span class="required">*</span></label>
						<input type="text" class="input-text" name="account_first_name" id="account_first_name" value="">
					</p>
					<p class="form-row form-row-last">
						<label for="account_last_name">Last name <span class="required">*</span></label>
						<input type="text" class="input-text" name="account_last_name" id="account_last_name" value="">
					</p>
					<div class="clear"></div>
					<p class="form-row form-row-wide">
						<label for="account_email">Email address <span class="required">*</span></label>
						<input type="email" class="input-text" name="account_email" id="account_email" value="">
					</p>
					<fieldset>
						<legend>Password Change</legend>
						<p class="form-row form-row-wide">
							<label for="password_current">Current Password (leave blank to leave unchanged)</label>
							<input type="password" class="input-text" name="password_current" id="password_current">
						</p>
						<p class="form-row form-row-wide">
							<label for="password_1">New Password (leave blank to leave unchanged)</label>
							<input type="password" class="input-text" name="password_1" id="password_1">
						</p>
						<p class="form-row form-row-wide">
							<label for="password_2">Confirm New Password</label>
							<input type="password" class="input-text" name="password_2" id="password_2">
						</p>
					</fieldset>
					<div class="clear"></div>
					<p>
						<input type="submit" class="button" name="save_account_details" value="Save changes">
					</p>
				</form>
			</div>
		<?php
		} else { ?>
			<div class="edit-account"><?php wc_get_template( 'myaccount/form-edit-account.php', array( 'user' => get_user_by( 'id', get_current_user_id() ) ) ); ?></div>
		<?php }

		$this->module_end( $options );
	}
}

add_action('dslc_hook_register_modules',
	create_function( '', 'return dslc_register_module( "LCWoo_edit_account" );' )
);
