<?php

/**
 * Module View Order
 */
class LCWoo_View_Order extends DSLC_Module {

	/**
	 * ID
	 *
	 * @var string
	 */
	var $module_id;

	/**
	 * Title
	 *
	 * @var string
	 */
	var $module_title;

	/**
	 * Icon
	 *
	 * @var string
	 */
	var $module_icon;

	/**
	 * Category
	 *
	 * @var string
	 */
	var $module_category;

	/**
	 * Construct
	 */
	function __construct() {

		$this->module_id = 'LCWoo_View_Order';
		$this->module_title = __( 'View Order', 'lc-woo-integration' );
		$this->module_icon = 'list-ul';
		$this->module_category = 'Woo Account';

	}

	/**
	 * Options
	 */
	function options() {
		$options = array(

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_general_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_general_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_general_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_general_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_general_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_general_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_general_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_general_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
			),

			/**
			 * Typography
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_typography_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_typography_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_typography_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_typography_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_typography_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_typography_text_align',
				'std' => 'left',
				'type' => 'select',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
				'choices' => array(
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
					array(
						'label' => __( 'Center', 'lc-woo-integration' ),
						'value' => 'center',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Justify', 'lc-woo-integration' ),
						'value' => 'justify',
					),
				),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_typography_margin_bottom',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Typography', 'lc-woo-integration' ),
			),

			/**
			 * Button
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_button_bg_color',
				'std' => '#60646c',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again a',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG:Hover Color', 'lc-woo-integration' ),
				'id' => 'css_button_bg_hover_color',
				'std' => '#7E8085',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again a:hover',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_button_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again a',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_button_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again a',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_button_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again a',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_button_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again a',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_button_color',
				'std' => '#ffffff',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again a',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_button_form_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again a',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_button_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again a',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_button_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again a',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_button_line_height',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again a',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_button_padding_vertical',
				'std' => '8',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again a',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_button_padding_horizontal',
				'std' => '12',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again a',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_button_margin_bottom',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Button', 'lc-woo-integration' ),
			),

			/**
			 * Order Details
			 */

			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_order_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Order Details', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_order_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_order_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_order_border_trbl',
				'std' => '',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Order Details', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_order_margin_bottom',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details', 'lc-woo-integration' ),
			),

			/**
			 * Order Details > Title
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_order_details_title_color',
				'std' => '#484c51',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order h2',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Order Details > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_order_details_title_form_font_size',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order h2',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_order_details_title_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order h2',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Order Details > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_order_details_title_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order h2',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Order Details > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_order_details_title_line_height',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order h2',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_order_details_title_margin_bottom',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order h2',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Title', 'lc-woo-integration' ),
			),

			/**
			 * Order Details > Shop Table > Titles
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_title_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details thead tr th',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Order Details > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_title_border_color',
				'std' => '#c7c7c7',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details thead tr th',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Order Details > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_title_border_width',
				'std' => '2',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details thead tr th',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_title_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details thead tr th',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_title_border_trbl',
				'std' => 'bottom',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details thead tr th',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Order Details > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_title_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details thead tr th',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Order Details > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_title_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details thead tr th',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_title_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details thead tr th',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Order Details > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_title_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details thead tr th',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Order Details > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_title_line_height',
				'std' => '21',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details thead tr th',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Text Transform', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_title_text_transform',
				'std' => 'uppercase',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'None', 'lc-woo-integration' ),
						'value' => 'none',
					),
					array(
						'label' => __( 'Capitalize', 'lc-woo-integration' ),
						'value' => 'capitalize',
					),
					array(
						'label' => __( 'Uppercase', 'lc-woo-integration' ),
						'value' => 'uppercase',
					),
					array(
						'label' => __( 'Lowercase', 'lc-woo-integration' ),
						'value' => 'lowercase',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details thead tr th',
				'affect_on_change_rule' => 'text-transform',
				'section' => 'styling',
				'tab' => __( 'Order Details > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_title_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details thead tr th',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_title_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details thead tr th',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Titles', 'lc-woo-integration' ),
			),

			/**
			 * Order Details > Shop Table > Items
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_items_bg_color',
				'std' => 'rgba(0, 0, 0, 0.02)',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Order Details > Shop Table > Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_items_border_color',
				'std' => '#c4c4c4',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Order Details > Shop Table > Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_items_border_width',
				'std' => '1',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_items_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_items_border_trbl',
				'std' => 'top',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Order Details > Shop Table > Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_items_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td, table.order_details tbody tr td a',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Order Details > Shop Table > Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_items_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_items_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Order Details > Shop Table > Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_items_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Order Details > Shop Table > Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_items_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_items_padding_vertical',
				'std' => '8',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_items_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Items', 'lc-woo-integration' ),
			),

			/**
			 * Order Details > Shop Table > Items > Variation
			 */

			array(
				'label' => __( 'One - Color', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_items_variation_one_color',
				'std' => '#60646c',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td dl.variation dt',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Order Details > Shop Table > Items > Variation', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'One - Font Size', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_items_variation_one_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td dl.variation dt',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Items > Variation', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'One - Font Weight', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_items_variation_one_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td dl.variation dt',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Order Details > Shop Table > Items > Variation', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'One - Line Height', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_items_variation_one_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td dl.variation dt',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Items > Variation', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Two - Color', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_items_variation_two_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td dl.variation dd p',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Order Details > Shop Table > Items > Variation', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Two - Font Size', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_items_variation_two_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td dl.variation dd p',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Items > Variation', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Two - Font Weight', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_items_variation_two_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td dl.variation dd p',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Order Details > Shop Table > Items > Variation', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Two - Line Height', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_items_variation_two_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td dl.variation dd p',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Items > Variation', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_items_variation_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td dl.variation',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Order Details > Shop Table > Items > Variation', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_items_variation_two_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td dl.variation dd p',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Items > Variation', 'lc-woo-integration' ),
			),

			/**
			 * Order Details > Shop Table > Cart > Title
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_cart_title_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Order Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_cart_title_border_color',
				'std' => '#c4c4c4',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Order Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_cart_title_border_width',
				'std' => '1',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_cart_title_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_cart_title_border_trbl',
				'std' => 'top',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Order Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_cart_title_title_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr th',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Order Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_cart_title_title_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr th',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_cart_title_title_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr th',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Order Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_cart_title_title_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr th',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Order Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_cart_title_title_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr th',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_cart_title_title_padding_vertical',
				'std' => '9',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr th',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_cart_title_title_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr th',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),

			/**
			 * Order Details > Shop Table > Cart > Item
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_cart_item_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr td',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Order Details > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_cart_item_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr td',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_cart_item_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr td',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Order Details > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_cart_item_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr td',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Order Details > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_cart_item_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr td',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_cart_item_padding_vertical',
				'std' => '9',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr td',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_order_details_shop_table_cart_item_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr td',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Order Details > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),

			/**
			 * Customer Details
			 */

			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_customer_details_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Customer Details', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_customer_details_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Customer Details', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_customer_details_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Customer Details', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_customer_details_trbl',
				'std' => 'top right bottom',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Customer Details', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_customer_details_bottom',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Customer Details', 'lc-woo-integration' ),
			),

			/**
			 * Customer Details > Title
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_customer_details_title_color',
				'std' => '#484c51',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order header h2, .woo-view-order header',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_customer_details_title_form_font_size',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order header h2, .woo-view-order header',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Customer Details > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_customer_details_title_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order header h2, .woo-view-order header',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Customer Details > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_customer_details_title_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order header h2, .woo-view-order header',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_customer_details_title_line_height',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order header h2, .woo-view-order header',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Customer Details > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_customer_details_title_margin_bottom',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order header h2, .woo-view-order header',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Customer Details > Title', 'lc-woo-integration' ),
			),

			/**
			 * Customer Details > Shop Table > Cart > Title
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_title_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr th',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_title_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr th',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_title_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr th',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Customer Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_title_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr th',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Customer Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_title_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr th',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_title_title_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr th',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_title_title_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr th',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Customer Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_title_title_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr th',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Customer Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_title_title_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr th',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_title_title_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr th',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Customer Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_title_title_padding_vertical',
				'std' => '9',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr th',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Customer Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_title_title_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr th',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Customer Details > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),

			/**
			 * Customer Details > Shop Table > Cart > Item
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_item_bg_color',
				'std' => '#f6f6f6',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr td',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_item_border_color',
				'std' => '#EFEFEF',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr td',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_item_border_width',
				'std' => '1',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr td',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Customer Details > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_item_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr td',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Customer Details > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_item_border_trbl',
				'std' => 'bottom',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr td',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_item_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr td',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_item_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr td',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Customer Details > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_item_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr td',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Customer Details > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_item_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr td',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Customer Details > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_item_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr td',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Customer Details > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_item_padding_vertical',
				'std' => '9',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr td',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Customer Details > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_customer_details_shop_table_cart_item_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr td',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Customer Details > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),

			/**
			 * Addresses > Billing and Shipping
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses .col-1, .woo-view-order .addresses .col-2',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Addresses > Billing and Shipping', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses .col-1, .woo-view-order .addresses .col-2',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Addresses > Billing and Shipping', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses .col-1, .woo-view-order .addresses .col-2',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses > Billing and Shipping', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses .col-1, .woo-view-order .addresses .col-2',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses > Billing and Shipping', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses .col-1, .woo-view-order .addresses .col-2',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Addresses > Billing and Shipping', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses .col-1, .woo-view-order .addresses .col-2',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses > Billing and Shipping', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses .col-1, .woo-view-order .addresses .col-2',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses > Billing and Shipping', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_margin_bottom',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses .col-1, .woo-view-order .addresses .col-2',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses > Billing and Shipping', 'lc-woo-integration' ),
			),

			/**
			 * Addresses > Billing and Shipping > Title
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_title_color',
				'std' => '#484c51',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses h3',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Addresses > Billing and Shipping > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_title_font_size',
				'std' => '21',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses h3',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses > Billing and Shipping > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_title_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses h3',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Addresses > Billing and Shipping > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_title_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses h3',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Addresses > Billing and Shipping > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_title_line_height',
				'std' => '27',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses h3',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses > Billing and Shipping > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_title_margin_bottom',
				'std' => '18',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses h3',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses > Billing and Shipping > Title', 'lc-woo-integration' ),
			),

			/**
			 * Addresses > Billing and Shipping > Address
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_address_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses address',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Addresses > Billing and Shipping > Address', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_address_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses address',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses > Billing and Shipping > Address', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_address_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses address',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Addresses > Billing and Shipping > Address', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_address_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses address',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Addresses > Billing and Shipping > Address', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_address_line_height',
				'std' => '23',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses address',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Addresses > Billing and Shipping > Address', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Style', 'lc-woo-integration' ),
				'id' => 'css_addresses_billing_and_shipping_address_font_style',
				'std' => 'italic',
				'type' => 'select',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses address',
				'affect_on_change_rule' => 'font-style',
				'section' => 'styling',
				'tab' => __( 'Addresses > Billing and Shipping > Address', 'lc-woo-integration' ),
				'choices' => array(
					array(
						'label' => __( 'Normal', 'lc-woo-integration' ),
						'value' => 'normal',
					),
					array(
						'label' => __( 'Italic', 'lc-woo-integration' ),
						'value' => 'italic',
					),
				),
			),

			/**
			 * Responsive Tablet
			 */

			array(
				'label' => __( 'Responsive', 'lc-woo-integration' ),
				'id' => 'css_res_t',
				'std' => 'disabled',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Disabled', 'lc-woo-integration' ),
						'value' => 'disabled',
					),
					array(
						'label' => __( 'Enabled', 'lc-woo-integration' ),
						'value' => 'enabled',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_general_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_general_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_typography_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_typography_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_typography_margin_bottom',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_button_form_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again a',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_button_line_height',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again a',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_button_padding_vertical',
				'std' => '8',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again a',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_button_padding_horizontal',
				'std' => '12',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again a',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_button_margin_bottom',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_margin_bottom',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_title_form_font_size',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order h2',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_title_line_height',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order h2',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Title - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_title_margin_bottom',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order h2',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Titles - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_shop_table_title_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details thead tr th',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Titles - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_shop_table_title_line_height',
				'std' => '21',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details thead tr th',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Titles - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_shop_table_title_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details thead tr th',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Titles - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_shop_table_title_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details thead tr th',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Items - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_shop_table_items_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Items - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_shop_table_items_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Items - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_shop_table_items_padding_vertical',
				'std' => '8',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Items - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_shop_table_items_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Items > Variation One - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_shop_table_items_variation_one_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td dl.variation dt',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Items > Variation One - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_shop_table_items_variation_one_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td dl.variation dt',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Items > Variation Two - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_shop_table_items_variation_two_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td dl.variation dd p',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Items > Variation Two - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_shop_table_items_variation_two_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td dl.variation dd p',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Items > Variation - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_shop_table_items_variation_two_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td dl.variation dd p',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Cart > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_shop_table_cart_title_title_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr th',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Cart > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_shop_table_cart_title_title_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr th',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Cart > Title - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_shop_table_cart_title_title_padding_vertical',
				'std' => '9',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr th',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Cart > Title - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_shop_table_cart_title_title_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr th',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Cart > Item - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_shop_table_cart_item_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr td',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Cart > Item - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_shop_table_cart_item_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr td',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Cart > Item - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_shop_table_cart_item_padding_vertical',
				'std' => '9',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr td',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Cart > Item - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_order_details_shop_table_cart_item_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr td',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_customer_details_bottom',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_customer_details_title_form_font_size',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order header h2, .woo-view-order header',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_customer_details_title_line_height',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order header h2, .woo-view-order header',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details > Title - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_customer_details_title_margin_bottom',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order header h2, .woo-view-order header',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details > Shop Table > Cart > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_customer_details_shop_table_cart_title_title_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr th',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details > Shop Table > Cart > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_customer_details_shop_table_cart_title_title_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr th',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details > Shop Table > Cart > Title - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_customer_details_shop_table_cart_title_title_padding_vertical',
				'std' => '9',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr th',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details > Shop Table > Cart > Title - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_customer_details_shop_table_cart_title_title_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr th',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details > Shop Table > Cart > Item - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_customer_details_shop_table_cart_item_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr td',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details > Shop Table > Cart > Item - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_customer_details_shop_table_cart_item_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr td',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details > Shop Table > Cart > Item - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_customer_details_shop_table_cart_item_padding_vertical',
				'std' => '9',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr td',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details > Shop Table > Cart > Item - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_customer_details_shop_table_cart_item_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr td',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_addresses_billing_and_shipping_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses .col-1, .woo-view-order .addresses .col-2',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_addresses_billing_and_shipping_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses .col-1, .woo-view-order .addresses .col-2',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_addresses_billing_and_shipping_margin_bottom',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses .col-1, .woo-view-order .addresses .col-2',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_addresses_billing_and_shipping_title_font_size',
				'std' => '21',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses h3',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_addresses_billing_and_shipping_title_line_height',
				'std' => '27',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses h3',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping > Title - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_addresses_billing_and_shipping_title_margin_bottom',
				'std' => '18',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses h3',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping > Address - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_addresses_billing_and_shipping_address_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses address',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping > Address - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_addresses_billing_and_shipping_address_line_height',
				'std' => '23',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses address',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),

			/**
			 * Responsive Phone
			 */

			array(
				'label' => __( 'Responsive', 'lc-woo-integration' ),
				'id' => 'css_res_p',
				'std' => 'disabled',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Disabled', 'lc-woo-integration' ),
						'value' => 'disabled',
					),
					array(
						'label' => __( 'Enabled', 'lc-woo-integration' ),
						'value' => 'enabled',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_general_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_general_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_typography_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_typography_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_typography_margin_bottom',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_button_form_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again a',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_button_line_height',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again a',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_button_padding_vertical',
				'std' => '8',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again a',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_button_padding_horizontal',
				'std' => '12',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again a',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_button_margin_bottom',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order p.order-again',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_margin_bottom',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_title_form_font_size',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order h2',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_title_line_height',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order h2',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Title - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_title_margin_bottom',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order h2',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Titles - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_shop_table_title_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details thead tr th',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Titles - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_shop_table_title_line_height',
				'std' => '21',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details thead tr th',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Titles - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_shop_table_title_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details thead tr th',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Titles - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_shop_table_title_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details thead tr th',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Items - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_shop_table_items_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Items - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_shop_table_items_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Items - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_shop_table_items_padding_vertical',
				'std' => '8',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Items - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_shop_table_items_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Items > Variation One - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_shop_table_items_variation_one_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td dl.variation dt',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Items > Variation One - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_shop_table_items_variation_one_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td dl.variation dt',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Items > Variation Two - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_shop_table_items_variation_two_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td dl.variation dd p',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Items > Variation Two - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_shop_table_items_variation_two_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td dl.variation dd p',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Items > Variation - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_shop_table_items_variation_two_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tbody tr td dl.variation dd p',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Cart > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_shop_table_cart_title_title_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr th',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Cart > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_shop_table_cart_title_title_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr th',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Cart > Title - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_shop_table_cart_title_title_padding_vertical',
				'std' => '9',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr th',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Cart > Title - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_shop_table_cart_title_title_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr th',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Cart > Item - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_shop_table_cart_item_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr td',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Cart > Item - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_shop_table_cart_item_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr td',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Cart > Item - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_shop_table_cart_item_padding_vertical',
				'std' => '9',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr td',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Order Details > Shop Table > Cart > Item - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_order_details_shop_table_cart_item_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.order_details tfoot tr td',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_customer_details_bottom',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_customer_details_title_form_font_size',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order header h2, .woo-view-order header',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_customer_details_title_line_height',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order header h2, .woo-view-order header',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details > Title - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_customer_details_title_margin_bottom',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order header h2, .woo-view-order header',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details > Shop Table > Cart > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_customer_details_shop_table_cart_title_title_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr th',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details > Shop Table > Cart > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_customer_details_shop_table_cart_title_title_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr th',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details > Shop Table > Cart > Title - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_customer_details_shop_table_cart_title_title_padding_vertical',
				'std' => '9',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr th',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details > Shop Table > Cart > Title - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_customer_details_shop_table_cart_title_title_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr th',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details > Shop Table > Cart > Item - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_customer_details_shop_table_cart_item_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr td',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details > Shop Table > Cart > Item - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_customer_details_shop_table_cart_item_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr td',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details > Shop Table > Cart > Item - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_customer_details_shop_table_cart_item_padding_vertical',
				'std' => '9',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr td',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Customer Details > Shop Table > Cart > Item - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_customer_details_shop_table_cart_item_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order table.customer_details tr td',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_addresses_billing_and_shipping_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses .col-1, .woo-view-order .addresses .col-2',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_addresses_billing_and_shipping_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses .col-1, .woo-view-order .addresses .col-2',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_addresses_billing_and_shipping_margin_bottom',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses .col-1, .woo-view-order .addresses .col-2',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_addresses_billing_and_shipping_title_font_size',
				'std' => '21',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses h3',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_addresses_billing_and_shipping_title_line_height',
				'std' => '27',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses h3',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping > Title - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_addresses_billing_and_shipping_title_margin_bottom',
				'std' => '18',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses h3',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping > Address - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_addresses_billing_and_shipping_address_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses address',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Addresses > Billing and Shipping > Address - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_addresses_billing_and_shipping_address_line_height',
				'std' => '23',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woo-view-order .addresses address',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
		);

		$options = array_merge( $options, $this->shared_options( 'animation_options' ) );
		$options = array_merge( $options, $this->presets_options() );

		return apply_filters( 'dslc_module_options', $options, $this->module_id );
	}

	/**
	 * Output
	 *
	 * @param array $options
	 */
	function output( $options ) {

		$this->module_start($options);

		global $dslc_active;

		if ( 'dslc_templates' === get_post_type() || $dslc_active ) {
		?>
			<div class='woo-view-order'>
				<p class="order-info">Order #<mark class="order-number">1</mark> was placed on <mark class="order-date">October 12, 2015</mark> and is currently <mark class="order-status">Completed</mark>.</p>
				<h2>Order Details</h2>
				<table class="shop_table order_details">
					<thead>
						<tr>
							<th class="product-name">Product</th>
							<th class="product-total">Total</th>
						</tr>
					</thead>
					<tbody>
						<tr class="order_item">
							<td class="product-name">
								<a href="">Woo Product</a> <strong class="product-quantity">× 1</strong>
								<dl class="variation">
									<dt class="variation-pa_color">color:</dt>
									<dd class="variation-pa_color"><p>Black</p></dd>
								</dl>
							</td>
							<td class="product-total"><span class="amount">£2.00</span></td>
						</tr>
					</tbody>
					<tfoot>
						<tr>
							<th scope="row">Subtotal:</th>
							<td><span class="amount">£2.00</span></td>
						</tr>
						<tr>
							<th scope="row">Shipping:</th>
							<td>Free Shipping</td>
						</tr>
						<tr>
							<th scope="row">Payment Method:</th>
							<td>Cheque Payment</td>
						</tr>
						<tr>
							<th scope="row">Total:</th>
							<td><span class="amount">£2.00</span></td>
						</tr>
					</tfoot>
				</table>
				<p class="order-again"><a href="#" class="button">Order Again</a></p>
				<header>Customer Details</header>
				<table class="shop_table shop_table_responsive customer_details">
					<tbody>
						<tr>
							<th>Email:</th>
							<td>test@woo.com</td>
						</tr>
						<tr>
							<th>Telephone:</th>
							<td>4084048219</td>
						</tr>
					</tbody>
				</table>
				<div class="col2-set addresses">
					<div class="col-1">
						<header class="title"><h3>Billing Address</h3></header>
						<address>User<br>Company<br>San Francisco<br>ap. 20<br>Us, CA 90210<br>United States (US)</address>
					</div>
					<div class="col-2">
						<header class="title"><h3>Shipping Address</h3></header>
						<address>User<br>Company<br>San Francisco<br>ap. 20<br>Us, CA 90210<br>United States (US)</address>
					</div>
				</div>
			</div>
		<?php
		} else { ?>
			<div class='woo-view-order'>
				<?php

				global $wp;
				$order_id  = absint( $wp->query_vars['view-order'] );
				$order = wc_get_order( $order_id );
				$view_order = new WC_Shortcode_My_Account;
				$view_order->output( $order_id );

				?>
			</div>
		<?php }

		$this->module_end( $options );
	}
}

add_action('dslc_hook_register_modules',
	create_function( '', 'return dslc_register_module( "LCWoo_View_Order" );' )
);
