<?php

/**
 * The Setting Tab class.
 */
class LCWOO_Settings_Tab {

	/**
	 * Post type.
	 *
	 * @var string
	 */

	public $post_type = 'template';

	/**
	 * ID.
	 *
	 * @var string
	 */

	public $id = 'system_templates';

	/**
	 * Сreates the desired settings
	 */
	function __construct() {

	    // Add settings tab.
	    add_filter( 'woocommerce_settings_tabs_array', array( $this, 'woocommerce_settings_tabs_array' ), 50 );

	    // Show settings tab.
	    add_action( 'woocommerce_settings_tabs_'.$this->id, array( $this, 'show_settings_tab' ) );

	    // Save settings tab.
	    add_action( 'woocommerce_update_options_'.$this->id, array( $this, 'update_settings_tab' ) );

	    // Add tabs select field.
	    add_action( 'woocommerce_admin_field_'.$this->post_type, array( $this, 'show_'.$this->post_type.'_field' ), 10 );

	    // Save tabs select field.
	    add_action( 'woocommerce_update_option_'.$this->post_type, array( $this, 'save_'.$this->post_type.'_field' ), 10 );
	}

	/**
	 * Settings Tabs
	 *
	 * @param type $settings_tabs
	 */
	function woocommerce_settings_tabs_array( $settings_tabs ) {

	    $settings_tabs[ $this->id ] = __( 'Additional Templates', 'woocommerce-additional-templates' );
	    return $settings_tabs;
	}

	/**
	 * Show Settings Tabs
	 */
	function show_settings_tab() {
	    woocommerce_admin_fields( $this->get_settings() );
	}

	/**
	 * Update Settings Tabs
	 */
	function update_settings_tab() {
	    woocommerce_update_options( $this->get_settings() );
	}

	/**
	 * Get Settings
	 */
	function get_settings() {
	    $settings = array(
	        'section_title_accounts' => array(
	            'name'     => __( 'Accounts Templates', 'woocommerce-accounts-templates' ),
	            'type'     => 'title',
	            'desc'     => '',
	            'id'       => 'wc_settings_tab_section_title_account',
	        ),
	        'view_order_template' => array(
	            'title'    => __( 'View Order', 'woocommerce' ),
	            'type'     => $this->post_type,
	            'desc_tip' => true,
	            'default'  => '',
	            'id'       => 'lcwoo_woocommerce_view_order_template_id',
	        ),
	        'edit_account_template' => array(
	            'title'    => __( 'Edit Account', 'woocommerce' ),
	            'type'     => $this->post_type,
	            'desc_tip' => true,
	            'default'  => '',
	            'id'       => 'lcwoo_woocommerce_edit_account_template_id',
	        ),
	        'edit_address_template' => array(
	            'title'    => __( 'Edit Address', 'woocommerce' ),
	            'type'     => $this->post_type,
	            'desc_tip' => true,
	            'default'  => '',
	            'id'       => 'lcwoo_woocommerce_edit_address_template_id',
	        ),
	        'login_template' => array(
	            'title'    => __( 'Login', 'woocommerce' ),
	            'type'     => $this->post_type,
	            'desc_tip' => true,
	            'default'  => '',
	            'id'       => 'lcwoo_woocommerce_login_template_id',
	        ),
	        'lost_password_template' => array(
	            'title'    => __( 'Lost Password', 'woocommerce' ),
	            'type'     => $this->post_type,
	            'desc_tip' => true,
	            'default'  => '',
	            'id'       => 'lcwoo_woocommerce_lost_password_template_id',
	        ),
	        'section_accounts_end' => array(
	            'type' => 'sectionend',
	            'id'   => 'wc_settings_tab_section_title_account',
	        ),
	        'section_title_orders' => array(
	            'name'     => __( 'Orders Templates', 'woocommerce-orders-templates' ),
	            'type'     => 'title',
	            'desc'     => '',
	            'id'       => 'wc_settings_tab_section_title_orders',
	        ),
	        'order_pay_template' => array(
	            'title'    => __( 'Order Pay', 'woocommerce' ),
	            'type'     => $this->post_type,
	            'desc_tip' => true,
	            'default'  => '',
	            'id'       => 'lcwoo_woocommerce_order_pay_template_id',
	        ),
	        'order_received_template' => array(
	            'title'    => __( 'Order Received', 'woocommerce' ),
	            'type'     => $this->post_type,
	            'desc_tip' => true,
	            'default'  => '',
	            'id'       => 'lcwoo_woocommerce_order_received_template_id',
	        ),
	        'section_orders_end' => array(
	            'type' => 'sectionend',
	            'id'   => 'wc_settings_tab_section_title_orders',
	        ),
	    );
	    return apply_filters( 'wc_settings_tab_settings', $settings );
	}

	/**
	 * Show Template field
	 *
	 * @param type $field
	 */
	function show_template_field( $field ) {
	    global $woocommerce;
	    ?><tr valign="top">
	        <th scope="row" class="titledesc">
	            <label for="<?php echo esc_attr( $field['id'] ); ?>"><?php echo esc_html( $field['title'] ); ?></label>
	        </th>
	        <td class="forminp forminp-<?php echo sanitize_title( $field['type'] ) ?>">
	            <p class="form-field custom_product_tabs">
	                <select id="custom_product_tabs" style="width: 50%;" name="<?php echo $field['id'];?>" class="ajax_chosen_select_tabs"  data-placeholder="<?php _e( 'Search for a custom template' ); ?>">
	                    <?php
	                        $template_id = get_option( $field['id'] );
	                        $type = 'dslc_templates';
	                        $args = array(
	                            'post_type' => $type,
	                            'post_status' => 'publish',
	                            'posts_per_page' => -1,
	                            'ignore_sticky_posts' => 1,
	                            'orderby' => 'meta_value',
	                            'meta_key' => 'dslc_template_type',
	                            'order' => 'DESC',
	                        );
	                        $my_query = null;
	                        $my_query = new WP_Query( $args );

	                    if ( $my_query->have_posts() ) {
	                        while ( $my_query->have_posts() ) : $my_query->the_post(); ?>
	                                <option value="<?php the_ID(); ?>" <?php selected( get_the_ID(), $template_id ); ?> ><?php the_title(); ?></option>
	                            <?php
	                        endwhile;
	                    }
	                    ?>
	                </select>
	            </p>
	        </td>
	    </tr><?php
	    add_action( 'admin_footer', array( $this, 'ajax_footer_js' ) );
	}

	/**
	 * Save Template field
	 *
	 * @param type $field
	 */
	function save_template_field( $field ) {

	    if ( isset( $_POST[ $field['id'] ] ) ) {
	        $option_value = $_POST[ $field['id'] ];
	        update_option( $field['id'], $option_value );
	    } else {
	        delete_option( $field['id'] );
	    }
	}

	/**
	 * Ajax Footer Javascript
	 */
	function ajax_footer_js() {
	    ?>
	    <script type="text/javascript">
	    jQuery(document).ready(function($){
	        // Ajax Chosen Product Selectors
	        jQuery("select.ajax_chosen_select_tabs").select2({});
	    });
	    </script>
	    <?php
	}
}
new LCWOO_Settings_Tab();
