<?php

/**
 * Module Checkout
 */
class LCWoo_Checkout extends DSLC_Module {

	/**
	 * ID
	 *
	 * @var string
	 */
	var $module_id;

	/**
	 * Title
	 *
	 * @var string
	 */
	var $module_title;

	/**
	 * Icon
	 *
	 * @var string
	 */
	var $module_icon;

	/**
	 * Category
	 *
	 * @var string
	 */
	var $module_category;

	/**
	 * Construct
	 */
	function __construct() {

		$this->module_id = 'LCWoo_Checkout';
		$this->module_title = __( 'Checkout', 'lc-woo-integration' );
		$this->module_icon = 'check';
		$this->module_category = 'Woo Checkout';
	}

	/**
	 * Options
	 */
	function options() {
		$options = array(

			array(
				'label' => __( 'Show On', 'lc-woo-integration' ),
				'id' => 'css_show_on',
				'std' => 'desktop tablet phone',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Desktop', 'lc-woo-integration' ),
						'value' => 'desktop',
					),
					array(
						'label' => __( 'Tablet', 'lc-woo-integration' ),
						'value' => 'tablet',
					),
					array(
						'label' => __( 'Phone', 'lc-woo-integration' ),
						'value' => 'phone',
					),
				),
			),

			/**
			 * Info
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_info_bg_color',
				'std' => '#3D9CD2',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_info_border_color',
				'std' => '#3384B2',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_info_border_width',
				'std' => '1',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_info_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_info_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_info_color',
				'std' => '#ffffff',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_info_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_info_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_info_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_info_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Link - Color', 'lc-woo-integration' ),
				'id' => 'css_info_link_color',
				'std' => '#ffffff',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info a',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Link:hover - Color', 'lc-woo-integration' ),
				'id' => 'css_info_link_hover_color',
				'std' => '#c2d3e5',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info a:hover',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Link - Font Weight', 'lc-woo-integration' ),
				'id' => 'css_info_link_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info a',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_info_text_align',
				'std' => 'left',
				'type' => 'select',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Info', 'lc-woo-integration' ),
				'choices' => array(
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
					array(
						'label' => __( 'Center', 'lc-woo-integration' ),
						'value' => 'center',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Justify', 'lc-woo-integration' ),
						'value' => 'justify',
					),
				),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_info_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_info_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_info_padding_horizontal',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info', 'lc-woo-integration' ),
			),

			/**
			 * Info > Coupon
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_bg_color',
				'std' => '#EFEFEF',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=text]',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_border_color',
				'std' => '#000000',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=text]',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_border_width',
				'std' => '1',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=text]',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=text]',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=text]',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=text]',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=text]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=text]',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=text]',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=text]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - BG Color', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_button_bg_color',
				'std' => '#EF510E',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - BG:hover Color', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_button_bg_hover_color',
				'std' => '#EF510E',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=submit]:hover',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Color', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_button_color',
				'std' => '#ffffff',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Border Color', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_button_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Border Width', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_button_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Border Radius', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_button_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Borders', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_button_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_button_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Font Weight', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_button_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Font Family', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_button_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_button_line_height',
				'std' => '18',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Button - Width', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_button_width',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon .form-row input[type=submit]',
				'affect_on_change_rule' => 'width',
				'section' => 'styling',
				'min' => 1,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon .form-row input[type=submit]',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon .form-row input[type=submit]',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_info_coupon_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Coupon', 'lc-woo-integration' ),
			),

			/**
			 * Info > Login
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_info_login_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Info > Login', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Link - Color', 'lc-woo-integration' ),
				'id' => 'css_info_login_link_color',
				'std' => '#000000',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login a',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Info > Login', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Link:Hover - Color', 'lc-woo-integration' ),
				'id' => 'css_info_login_link_hover_color',
				'std' => '#000000',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login a:hover',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Info > Login', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_info_login_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Login', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_info_login_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Info > Login', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Link - Font Weight', 'lc-woo-integration' ),
				'id' => 'css_info_login_link_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login a',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Info > Login', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_info_login_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Info > Login', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_info_login_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Login', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_info_login_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Login', 'lc-woo-integration' ),
			),

			/**
			 * Info > Login > Label
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_info_login_label_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login label',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Info > Login > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Required - Color', 'lc-woo-integration' ),
				'id' => 'css_info_login_required_color',
				'std' => '#FF0000',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login label span.required',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Info > Login > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_info_login_label_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login label',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Login > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_info_login_label_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login label',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Info > Login > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_info_login_label_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login label',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Info > Login > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_info_login_label_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login label',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Login > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_info_login_label_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login label',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Login > Label', 'lc-woo-integration' ),
			),

			/**
			 * Info > Login > Input
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_info_login_input_bg_color',
				'std' => '#EFEFEF',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=text], form.login input[type=password]',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Info > Login > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_info_login_input_border_color',
				'std' => '#000000',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=text], form.login input[type=password]',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Info > Login > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_info_login_input_border_width',
				'std' => '1',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=text], form.login input[type=password]',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Login > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_info_login_input_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=text], form.login input[type=password]',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Login > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_info_login_input_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=text], form.login input[type=password]',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Info > Login > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_info_login_input_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=text], form.login input[type=password]',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Info > Login > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_info_login_input_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=text], form.login input[type=password]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Login > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_info_login_input_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=text], form.login input[type=password]',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Info > Login > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_info_login_input_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=text], form.login input[type=password]',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Info > Login > Input', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_info_login_input_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=text], form.login input[type=password]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Login > Input', 'lc-woo-integration' ),
			),

			/**
			 * Info > Login > Button
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_info_login_button_bg_color',
				'std' => '#EF510E',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=submit]',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Info > Login > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG:hover Color', 'lc-woo-integration' ),
				'id' => 'css_info_login_button_bg_hover_color',
				'std' => '#EF510E',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=submit]:hover',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Info > Login > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_info_login_button_color',
				'std' => '#ffffff',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=submit]',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Info > Login > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_info_login_button_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=submit]',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Info > Login > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_info_login_button_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=submit]',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Login > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_info_login_button_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=submit]',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Login > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_info_login_button_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=submit]',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Info > Login > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_info_login_button_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=submit]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Login > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_info_login_button_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=submit]',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Info > Login > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_info_login_button_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=submit]',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Info > Login > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_info_login_button_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=submit]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Login > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Width', 'lc-woo-integration' ),
				'id' => 'css_info_login_button_width',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login .form-row input[type=submit]',
				'affect_on_change_rule' => 'width',
				'section' => 'styling',
				'min' => 1,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'Info > Login > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_info_login_button_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login .form-row input[type=submit]',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Login > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_info_login_button_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login .form-row input[type=submit]',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Login > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_info_login_button_margin_bottom',
				'std' => '5',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login .form-row input[type=submit]',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Info > Login > Button', 'lc-woo-integration' ),
			),

			/**
			 * Form
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_form_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields, .woocommerce-shipping-fields',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Form', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_form_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields, .woocommerce-shipping-fields',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Form', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_form_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields, .woocommerce-shipping-fields',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_form_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields, .woocommerce-shipping-fields',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_form_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields, .woocommerce-shipping-fields',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Form', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_form_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields, .woocommerce-shipping-fields',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_form_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields, .woocommerce-shipping-fields',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_form_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields, .woocommerce-shipping-fields',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form', 'lc-woo-integration' ),
			),

			/**
			 * Form > Title
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_form_title_color',
				'std' => '#484C51',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields h3, .woocommerce-shipping-fields h3 label',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Form > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_form_title_font_size',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields h3, .woocommerce-shipping-fields h3 label',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_form_title_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields h3, .woocommerce-shipping-fields h3 label',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Form > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_form_title_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields h3, .woocommerce-shipping-fields h3 label',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Form > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_form_title_line_height',
				'std' => '28',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields h3, .woocommerce-shipping-fields h3 label',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_form_title_text_align',
				'std' => 'left',
				'type' => 'select',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields h3, .woocommerce-shipping-fields h3 label',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Form > Title', 'lc-woo-integration' ),
				'choices' => array(
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
					array(
						'label' => __( 'Center', 'lc-woo-integration' ),
						'value' => 'center',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Justify', 'lc-woo-integration' ),
						'value' => 'justify',
					),
				),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_form_title_margin_bottom',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields h3, .woocommerce-shipping-fields h3 label',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form > Title', 'lc-woo-integration' ),
			),

			/**
			 * Form > Label
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_form_label_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields p label, .woocommerce-shipping-fields p label',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Form > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Required - Color', 'lc-woo-integration' ),
				'id' => 'css_form_label_required_color',
				'std' => '#FF0000',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields p label abbr.required, .woocommerce-shipping-fields p label abbr.required',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Form > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_form_label_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields p label, .woocommerce-shipping-fields p label',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_form_label_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields p label, .woocommerce-shipping-fields p label',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Form > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_form_label_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields p label, .woocommerce-shipping-fields p label',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Form > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_form_label_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields p label, .woocommerce-shipping-fields p label',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_form_label_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields p label, .woocommerce-shipping-fields p label',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_form_label_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields p label, .woocommerce-shipping-fields p label',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_form_label_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields p label, .woocommerce-shipping-fields p label',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form > Label', 'lc-woo-integration' ),
			),

			/**
			 * Form > Input/Textarea
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_form_input_bg_color',
				'std' => '#EFEFEF',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields input, .woocommerce-shipping-fields textarea, .woocommerce-shipping-fields input',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_form_input_border_color',
				'std' => '#D1D1D1',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields input, .woocommerce-shipping-fields textarea, .woocommerce-shipping-fields input',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_form_input_border_width',
				'std' => '1',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields input, .woocommerce-shipping-fields textarea, .woocommerce-shipping-fields input',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_form_input_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields input, .woocommerce-shipping-fields textarea, .woocommerce-shipping-fields input',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_form_input_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields input, .woocommerce-shipping-fields textarea, .woocommerce-shipping-fields input',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_form_input_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields input, .woocommerce-shipping-fields textarea, .woocommerce-shipping-fields input',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_form_input_form_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields input, .woocommerce-shipping-fields textarea, .woocommerce-shipping-fields input',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_form_input_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields input, .woocommerce-shipping-fields textarea, .woocommerce-shipping-fields input',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_form_input_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields input, .woocommerce-shipping-fields textarea, .woocommerce-shipping-fields input',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_form_input_line_height',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields input, .woocommerce-shipping-fields textarea, .woocommerce-shipping-fields input',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_form_input_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields input, .woocommerce-shipping-fields textarea, .woocommerce-shipping-fields input',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_form_input_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields input, .woocommerce-shipping-fields textarea, .woocommerce-shipping-fields input',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_form_input_padding_horizontal',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields input, .woocommerce-shipping-fields textarea, .woocommerce-shipping-fields input',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Min-Height Textarea', 'lc-woo-integration' ),
				'id' => 'css_form_input_min_height',
				'std' => '50',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-shipping-fields textarea',
				'affect_on_change_rule' => 'min-height',
				'section' => 'styling',
				'tab' => __( 'Form > Input/Textarea', 'lc-woo-integration' ),
				'min' => 50,
				'max' => 400,
				'ext' => 'px',
			),

			/**
			 * Form > Select
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_form_select_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lc-product-checkout .select2-container a, .lc-product-checkout select#billing_country, .lc-product-checkout select#billing_state, .lc-product-checkout select#shipping_country, .lc-product-checkout select#shipping_state',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Form > Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_form_select_border_color',
				'std' => '#CCCCCC',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lc-product-checkout .select2-container a, .lc-product-checkout select#billing_country, .lc-product-checkout select#billing_state, .lc-product-checkout select#shipping_country, .lc-product-checkout select#shipping_state',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Form > Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_form_select_border_width',
				'std' => '1',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lc-product-checkout .select2-container a, .lc-product-checkout select#billing_country, .lc-product-checkout select#billing_state, .lc-product-checkout select#shipping_country, .lc-product-checkout select#shipping_state',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form > Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_form_select_border_radius',
				'std' => '4',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lc-product-checkout .select2-container a, .lc-product-checkout select#billing_country, .lc-product-checkout select#billing_state, .lc-product-checkout select#shipping_country, .lc-product-checkout select#shipping_state',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form > Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_form_select_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lc-product-checkout .select2-container a, .lc-product-checkout select#billing_country, .lc-product-checkout select#billing_state, .lc-product-checkout select#shipping_country, .lc-product-checkout select#shipping_state',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Form > Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_form_select_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lc-product-checkout .select2-container a, .lc-product-checkout select#billing_country, .lc-product-checkout select#billing_state, .lc-product-checkout select#shipping_country, .lc-product-checkout select#shipping_state, .select2-default',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Form > Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_form_select_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lc-product-checkout .select2-container a, .lc-product-checkout select#billing_country, .lc-product-checkout select#billing_state, .lc-product-checkout select#shipping_country, .lc-product-checkout select#shipping_state',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form > Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_form_select_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lc-product-checkout .select2-container a, .lc-product-checkout select#billing_country, .lc-product-checkout select#billing_state, .lc-product-checkout select#shipping_country, .lc-product-checkout select#shipping_state',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Form > Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_form_select_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lc-product-checkout .select2-container a, .lc-product-checkout select#billing_country, .lc-product-checkout select#billing_state, .lc-product-checkout select#shipping_country, .lc-product-checkout select#shipping_state',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Form > Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_form_select_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lc-product-checkout .select2-container a, .lc-product-checkout select#billing_country, .lc-product-checkout select#billing_state, .lc-product-checkout select#shipping_country, .lc-product-checkout select#shipping_state',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form > Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_form_select_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lc-product-checkout .select2-container a, .lc-product-checkout select#billing_country, .lc-product-checkout select#billing_state, .lc-product-checkout select#shipping_country, .lc-product-checkout select#shipping_state',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form > Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_form_select_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lc-product-checkout .select2-container a, .lc-product-checkout select#billing_country, .lc-product-checkout select#billing_state, .lc-product-checkout select#shipping_country, .lc-product-checkout select#shipping_state',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form > Select', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_form_select_padding_horizontal',
				'std' => '7',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lc-product-checkout .select2-container a, .lc-product-checkout select#billing_country, .lc-product-checkout select#billing_state, .lc-product-checkout select#shipping_country, .lc-product-checkout select#shipping_state',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form > Select', 'lc-woo-integration' ),
			),

			/**
			 * Form Message > Error
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_form_message_error_bg_color',
				'std' => '#E2401C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Form Message > Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_form_message_error_border_color',
				'std' => '#C03718',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Form Message > Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_form_message_error_border_width',
				'std' => '1',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form Message > Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_form_message_error_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form Message > Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_form_message_error_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Form Message > Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_form_message_error_color',
				'std' => '#ffffff',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Form Message > Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_form_message_error_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form Message > Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_form_message_error_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Form Message > Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_form_message_error_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Form Message > Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_form_message_error_line_height',
				'std' => '29',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form Message > Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_form_message_error_text_align',
				'std' => 'left',
				'type' => 'select',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Form Message > Error', 'lc-woo-integration' ),
				'choices' => array(
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
					array(
						'label' => __( 'Center', 'lc-woo-integration' ),
						'value' => 'center',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Justify', 'lc-woo-integration' ),
						'value' => 'justify',
					),
				),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_form_message_error_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form Message > Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_form_message_error_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form Message > Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_form_message_error_padding_horizontal',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form Message > Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Input - Border Color', 'lc-woo-integration' ),
				'id' => 'css_form_message_error_input_border_color',
				'std' => '#E2401C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.form-row.woocommerce-invalid input.input-text',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Form Message > Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Input - Border Width', 'lc-woo-integration' ),
				'id' => 'css_form_message_error_input_border_width',
				'std' => '1',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.form-row.woocommerce-invalid input.input-text',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form Message > Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Input - Border Radius', 'lc-woo-integration' ),
				'id' => 'css_form_message_error_input_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.form-row.woocommerce-invalid input.input-text',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Form Message > Error', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Input - Borders', 'lc-woo-integration' ),
				'id' => 'css_form_message_error_input_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.form-row.woocommerce-invalid input.input-text',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Form Message > Error', 'lc-woo-integration' ),
			),

			/**
			 * Account
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_account_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.create-account p, #create-account p',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Account', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_account_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.create-account p, #create-account p',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Account', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_account_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.create-account p, #create-account p',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Account', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_account_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.create-account p, #create-account p',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Account', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_account_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.create-account p, #create-account p',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Account', 'lc-woo-integration' ),
			),

			/**
			 * Review
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_review_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Review', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_review_border_color',
				'std' => '#000000',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Review', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_review_border_width',
				'std' => '3',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_review_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_review_border_trbl',
				'std' => 'right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Review', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_review_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_review_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_review_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review', 'lc-woo-integration' ),
			),

			/**
			 * Review > Title
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_review_title_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_review_title_border_color',
				'std' => '#000000',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_review_title_border_width',
				'std' => '3',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_review_title_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_review_title_border_trbl',
				'std' => 'top right left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_review_title_color',
				'std' => '#484C51',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_review_title_font_size',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_review_title_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_review_title_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_review_title_line_height',
				'std' => '28',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_review_title_text_align',
				'std' => 'left',
				'type' => 'select',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
				'choices' => array(
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
					array(
						'label' => __( 'Center', 'lc-woo-integration' ),
						'value' => 'center',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Justify', 'lc-woo-integration' ),
						'value' => 'justify',
					),
				),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_review_title_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_review_title_padding_horizontal',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_review_title_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Title', 'lc-woo-integration' ),
			),

			/**
			 * Review > Shop Table > Titles
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_title_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table th.product-name, #order_review table th.product-total',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_title_border_color',
				'std' => '#c7c7c7',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table th.product-name, #order_review table th.product-total',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_title_border_width',
				'std' => '2',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table th.product-name, #order_review table th.product-total',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_title_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table th.product-name, #order_review table th.product-total',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_title_border_trbl',
				'std' => 'bottom',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table th.product-name, #order_review table th.product-total',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_title_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table th.product-name, #order_review table th.product-total',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_title_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table th.product-name, #order_review table th.product-total',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_title_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table th.product-name, #order_review table th.product-total',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Review > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_title_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table th.product-name, #order_review table th.product-total',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_title_line_height',
				'std' => '21',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table th.product-name, #order_review table th.product-total',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_title_text_align',
				'std' => 'left',
				'type' => 'select',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table th.product-name, #order_review table th.product-total',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Titles', 'lc-woo-integration' ),
				'choices' => array(
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
					array(
						'label' => __( 'Center', 'lc-woo-integration' ),
						'value' => 'center',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Justify', 'lc-woo-integration' ),
						'value' => 'justify',
					),
				),
			),
			array(
				'label' => __( 'Text Transform', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_title_text_transform',
				'std' => 'uppercase',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'None', 'lc-woo-integration' ),
						'value' => 'none',
					),
					array(
						'label' => __( 'Capitalize', 'lc-woo-integration' ),
						'value' => 'capitalize',
					),
					array(
						'label' => __( 'Uppercase', 'lc-woo-integration' ),
						'value' => 'uppercase',
					),
					array(
						'label' => __( 'Lowercase', 'lc-woo-integration' ),
						'value' => 'lowercase',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table th.product-name, #order_review table th.product-total',
				'affect_on_change_rule' => 'text-transform',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_title_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table th.product-name, #order_review table th.product-total',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Shop Table > Titles', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_title_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table th.product-name, #order_review table th.product-total',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Shop Table > Titles', 'lc-woo-integration' ),
			),

			/**
			 * Review > Shop Table > Items
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_items_bg_color',
				'std' => 'rgba(0, 0, 0, 0.02)',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item td.product-name, .cart_item td.product-total',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_items_border_color',
				'std' => '#c4c4c4',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item td.product-name, .cart_item td.product-total',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_items_border_width',
				'std' => '1',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item td.product-name, .cart_item td.product-total',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Shop Table > Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_items_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item td.product-name, .cart_item td.product-total',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Shop Table > Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_items_border_trbl',
				'std' => 'top',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item td.product-name, .cart_item td.product-total',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_items_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item td.product-name, .cart_item td.product-total',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_items_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item td.product-name, .cart_item td.product-total',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Shop Table > Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_items_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item td.product-name, .cart_item td.product-total',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Review > Shop Table > Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_items_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item td.product-name, .cart_item td.product-total',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_items_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item td.product-name, .cart_item td.product-total',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Shop Table > Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Text Align', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_items_text_align',
				'std' => 'left',
				'type' => 'select',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item td.product-name, .cart_item td.product-total',
				'affect_on_change_rule' => 'text-align',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Items', 'lc-woo-integration' ),
				'choices' => array(
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
					array(
						'label' => __( 'Center', 'lc-woo-integration' ),
						'value' => 'center',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Justify', 'lc-woo-integration' ),
						'value' => 'justify',
					),
				),
			),
			array(
				'label' => __( 'Text Transform', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_items_text_transform',
				'std' => 'none',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'None', 'lc-woo-integration' ),
						'value' => 'none',
					),
					array(
						'label' => __( 'Capitalize', 'lc-woo-integration' ),
						'value' => 'capitalize',
					),
					array(
						'label' => __( 'Uppercase', 'lc-woo-integration' ),
						'value' => 'uppercase',
					),
					array(
						'label' => __( 'Lowercase', 'lc-woo-integration' ),
						'value' => 'lowercase',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item td.product-name, .cart_item td.product-total',
				'affect_on_change_rule' => 'text-transform',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_items_padding_vertical',
				'std' => '8',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item td.product-name, .cart_item td.product-total',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Shop Table > Items', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_items_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item td.product-name, .cart_item td.product-total',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Shop Table > Items', 'lc-woo-integration' ),
			),

			/**
			 * Review > Shop Table > Variation
			 */

			array(
				'label' => __( 'One - Color', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_variation_dt_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name dt',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Variation', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Two - Color', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_variation_dd_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name dd',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Variation', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_variation_dt_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name dt, .cart_item .product-name dd',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Variation', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'One - Font Weight', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_variation_dd_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name dd',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Variation', 'lc-woo-integration' ),
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
			),
			array(
				'label' => __( 'Two - Font Weight', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_variation_font_weight',
				'std' => '500',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name dt',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Variation', 'lc-woo-integration' ),
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_variation_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name dt, .cart_item .product-name dd',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Variation', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_variation_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name dt, .cart_item .product-name dd',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Variation', 'lc-woo-integration' ),
				'ext' => 'px',
			),

			/**
			 * Review > Shop Table > Cart > Title
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal, #order_review table .shipping, #order_review table .order-total',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_border_color',
				'std' => '#c4c4c4',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal, #order_review table .shipping, #order_review table .order-total',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_border_width',
				'std' => '1',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal, #order_review table .shipping, #order_review table .order-total',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal, #order_review table .shipping, #order_review table .order-total',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_border_trbl',
				'std' => 'top',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal, #order_review table .shipping, #order_review table .order-total',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_title_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal th, #order_review table .shipping th, #order_review table .order-total th',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_title_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal th, #order_review table .shipping th, #order_review table .order-total th',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_title_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal th, #order_review table .shipping th, #order_review table .order-total th',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_title_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal th, #order_review table .shipping th, #order_review table .order-total th',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_title_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal th, #order_review table .shipping th, #order_review table .order-total th',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_title_padding_vertical',
				'std' => '9',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal th, #order_review table .shipping th, #order_review table .order-total th',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_title_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal th, #order_review table .shipping th, #order_review table .order-total th',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Shop Table > Cart > Title', 'lc-woo-integration' ),
			),

			/**
			 * Review > Shop Table > Cart > Item
			 */

			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_item_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal td, #order_review table .shipping td, #order_review table .order-total td',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_item_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal td, #order_review table .shipping td, #order_review table .order-total td',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_item_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal td, #order_review table .shipping td, #order_review table .order-total td',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Review > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_item_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal td, #order_review table .shipping td, #order_review table .order-total td',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Review > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_item_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal td, #order_review table .shipping td, #order_review table .order-total td',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_item_padding_vertical',
				'std' => '9',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal td, #order_review table .shipping td, #order_review table .order-total td',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_review_shop_table_cart_item_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal td, #order_review table .shipping td, #order_review table .order-total td',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Shop Table > Cart > Item', 'lc-woo-integration' ),
			),

			/**
			 * Review > Payment
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_review_payment_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_review_payment_border_color',
				'std' => 'rgba(0, 0, 0, 0.1)',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_review_payment_border_width',
				'std' => '3',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_review_payment_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_review_payment_border_trbl',
				'std' => 'top',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_review_payment_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order .payment_methods',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_review_payment_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order .payment_methods',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_review_payment_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order .payment_methods',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_review_payment_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order .payment_methods',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_review_payment_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_review_payment_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Payment', 'lc-woo-integration' ),
			),

			/**
			 * Review > Payment > Label
			 */

			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_border_color',
				'std' => 'rgba(0, 0, 0, 0.1)',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_border_width',
				'std' => '1',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_border_trbl',
				'std' => 'bottom',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Link - Color', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_link_color',
				'std' => '#000000',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment .payment_method_paypal label a',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Link:Hover - Color', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_link_hover_color',
				'std' => '#000000',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment .payment_method_paypal label a:hover',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_font_weight',
				'std' => '400',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Link - Font Weight', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_link_font_weight',
				'std' => '500',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment .payment_method_paypal label a',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_padding_horizontal',
				'std' => '6',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Img - Height', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_paypal_img_height',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment .payment_method_paypal img',
				'affect_on_change_rule' => 'height',
				'section' => 'styling',
				'min' => 1,
				'max' => 100,
				'ext' => 'px',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Img - Margin Top', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_paypal_img_margin_top',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment .payment_method_paypal img',
				'affect_on_change_rule' => 'margin-top',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Img - Margin Right', 'lc-woo-integration' ),
				'id' => 'css_review_payment_label_paypal_img_margin_right',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment .payment_method_paypal img',
				'affect_on_change_rule' => 'margin-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Payment > Label', 'lc-woo-integration' ),
			),

			/**
			 * Review > Payment > Box
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_review_payment_box_bg_color',
				'std' => '#F1F1F1',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li div.payment_box',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_review_payment_box_border_color',
				'std' => 'rgba(0, 0, 0, 0.1)',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li div.payment_box',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_review_payment_box_border_width',
				'std' => '1',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li div.payment_box',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_review_payment_box_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li div.payment_box',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_review_payment_box_border_trbl',
				'std' => 'top',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li div.payment_box',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_review_payment_box_color',
				'std' => '#60646C',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li div.payment_box',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_review_payment_box_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li div.payment_box',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_review_payment_box_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li div.payment_box',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_review_payment_box_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li div.payment_box',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_review_payment_box_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li div.payment_box',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_review_payment_box_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li div.payment_box',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_review_payment_box_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li div.payment_box',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Payment > Box', 'lc-woo-integration' ),
			),

			/**
			 * Review > Place Order
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_bg_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Review > Place Order', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Review > Place Order', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Place Order', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Place Order', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Review > Place Order', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Place Order', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Place Order', 'lc-woo-integration' ),
			),

			/**
			 * Review > Place Order > Button
			 */

			array(
				'label' => __( 'BG Color', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_button_bg_color',
				'std' => '#000000',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order input[type=submit]',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'BG:hover Color', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_button_bg_hover_color',
				'std' => '#000000',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order input[type=submit]:hover',
				'affect_on_change_rule' => 'background-color',
				'section' => 'styling',
				'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Color', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_button_color',
				'std' => '#ffffff',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order input[type=submit]',
				'affect_on_change_rule' => 'color',
				'section' => 'styling',
				'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Color', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_button_border_color',
				'std' => '',
				'type' => 'color',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order input[type=submit]',
				'affect_on_change_rule' => 'border-color',
				'section' => 'styling',
				'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Width', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_button_border_width',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order input[type=submit]',
				'affect_on_change_rule' => 'border-width',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Border Radius', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_button_border_radius',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order input[type=submit]',
				'affect_on_change_rule' => 'border-radius',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Borders', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_button_border_trbl',
				'std' => 'top right bottom left',
				'type' => 'checkbox',
				'choices' => array(
					array(
						'label' => __( 'Top', 'lc-woo-integration' ),
						'value' => 'top',
					),
					array(
						'label' => __( 'Right', 'lc-woo-integration' ),
						'value' => 'right',
					),
					array(
						'label' => __( 'Bottom', 'lc-woo-integration' ),
						'value' => 'bottom',
					),
					array(
						'label' => __( 'Left', 'lc-woo-integration' ),
						'value' => 'left',
					),
				),
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order input[type=submit]',
				'affect_on_change_rule' => 'border-style',
				'section' => 'styling',
				'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Size', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_button_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order input[type=submit]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Weight', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_button_font_weight',
				'std' => '300',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order input[type=submit]',
				'affect_on_change_rule' => 'font-weight',
				'section' => 'styling',
				'ext' => '',
				'min' => 100,
				'max' => 900,
				'increment' => 100,
				'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Font Family', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_button_font_family',
				'std' => '',
				'type' => 'font',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order input[type=submit]',
				'affect_on_change_rule' => 'font-family',
				'section' => 'styling',
				'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Line Height', 'lc-woo-integration' ),
				'id' => 'css_review_place_order_button_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order input[type=submit]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'styling',
				'ext' => 'px',
				'tab' => __( 'Review > Place Order > Button', 'lc-woo-integration' ),
			),

			/**
			 * Responsive Tablet
			 */

			array(
				'label' => __( 'Responsive Styling', 'lc-woo-integration' ),
				'id' => 'css_res_t',
				'std' => 'disabled',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Disabled', 'lc-woo-integration' ),
						'value' => 'disabled',
					),
					array(
						'label' => __( 'Enabled', 'lc-woo-integration' ),
						'value' => 'enabled',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_margin_bottom',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_padding_horizontal',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Coupon - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_coupon_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=text]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Coupon - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_coupon_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=text]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Coupon Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_coupon_button_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Coupon Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_coupon_button_line_height',
				'std' => '18',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Coupon Button - Width', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_coupon_button_width',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon .form-row input[type=submit]',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'min' => 1,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Coupon Button - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_coupon_button_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon .form-row input[type=submit]',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Coupon Button - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_coupon_button_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon .form-row input[type=submit]',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Coupon - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_coupon_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_login_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_login_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login Form - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_login_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login > Label - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_login_label_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login label',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login > Label - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_login_label_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login label',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login > Label Form - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_login_label_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login label',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login > Input - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_login_input_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=text], form.login input[type=password]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login > Input - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_login_input_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=text], form.login input[type=password]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login > Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_login_button_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=submit]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login > Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_login_button_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=submit]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login > Button - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_login_button_margin_bottom',
				'std' => '5',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login .form-row input[type=submit]',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login > Button - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_login_button_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login .form-row input[type=submit]',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login > Button - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_info_login_button_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login .form-row input[type=submit]',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields, .woocommerce-shipping-fields',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields, .woocommerce-shipping-fields',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields, .woocommerce-shipping-fields',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_title_font_size',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields h3, .woocommerce-shipping-fields h3 label',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_title_line_height',
				'std' => '28',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields h3, .woocommerce-shipping-fields h3 label',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Title - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_title_margin_bottom',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields h3, .woocommerce-shipping-fields h3 label',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Label - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_label_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields p label, .woocommerce-shipping-fields p label',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Label - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_label_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields p label, .woocommerce-shipping-fields p label',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Label - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_label_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields p label, .woocommerce-shipping-fields p label',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Label - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_label_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields p label, .woocommerce-shipping-fields p label',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Label - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_label_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields p label, .woocommerce-shipping-fields p label',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Input/Textarea - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_input_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields input, .woocommerce-shipping-fields textarea, .woocommerce-shipping-fields input',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Input/Textarea - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_input_line_height',
				'std' => '19',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields input, .woocommerce-shipping-fields textarea, .woocommerce-shipping-fields input',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Input/Textarea - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_input_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields input, .woocommerce-shipping-fields textarea, .woocommerce-shipping-fields input',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Input/Textarea - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_input_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields input, .woocommerce-shipping-fields textarea, .woocommerce-shipping-fields input',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Input/Textarea - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_input_padding_horizontal',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields input, .woocommerce-shipping-fields textarea, .woocommerce-shipping-fields input',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Select - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_select_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lc-product-checkout .select2-container a, .lc-product-checkout select#billing_country, .lc-product-checkout select#billing_state, .lc-product-checkout select#shipping_country, .lc-product-checkout select#shipping_state',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Select - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_select_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lc-product-checkout .select2-container a, .lc-product-checkout select#billing_country, .lc-product-checkout select#billing_state, .lc-product-checkout select#shipping_country, .lc-product-checkout select#shipping_state',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Select - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_select_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lc-product-checkout .select2-container a, .lc-product-checkout select#billing_country, .lc-product-checkout select#billing_state, .lc-product-checkout select#shipping_country, .lc-product-checkout select#shipping_state',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Select - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_select_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lc-product-checkout .select2-container a, .lc-product-checkout select#billing_country, .lc-product-checkout select#billing_state, .lc-product-checkout select#shipping_country, .lc-product-checkout select#shipping_state',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Select - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_select_padding_horizontal',
				'std' => '7',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lc-product-checkout .select2-container a, .lc-product-checkout select#billing_country, .lc-product-checkout select#billing_state, .lc-product-checkout select#shipping_country, .lc-product-checkout select#shipping_state',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form Message > Error - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_message_error_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form Message > Error - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_message_error_line_height',
				'std' => '29',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form Message > Error - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_message_error_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form Message > Error - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_message_error_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form Message > Error - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_form_message_error_padding_horizontal',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_title_font_size',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_title_line_height',
				'std' => '28',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Title - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_title_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Title - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_title_padding_horizontal',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Titles - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_title_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table th.product-name, #order_review table th.product-total',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Titles - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_title_line_height',
				'std' => '21',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table th.product-name, #order_review table th.product-total',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Titles - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_title_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table th.product-name, #order_review table th.product-total',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Titles - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_title_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table th.product-name, #order_review table th.product-total',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Items - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_items_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item td.product-name, .cart_item td.product-total',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Items - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_items_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item td.product-name, .cart_item td.product-total',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Items - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_items_padding_vertical',
				'std' => '8',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item td.product-name, .cart_item td.product-total',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Items - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_items_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item td.product-name, .cart_item td.product-total',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Cart Item > Name > Variation - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_variation_dt_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name dt, .cart_item .product-name dd',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Cart Item > Name > Variation - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_variation_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name dt, .cart_item .product-name dd',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_cart_title_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal th, #order_review table .shipping th, #order_review table .order-total th',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_cart_title_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal th, #order_review table .shipping th, #order_review table .order-total th',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Title - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_cart_title_padding_vertical',
				'std' => '9',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal th, #order_review table .shipping th, #order_review table .order-total th',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Title - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_cart_title_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal th, #order_review table .shipping th, #order_review table .order-total th',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Title - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_cart_title_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Item - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_cart_item_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal td, #order_review table .shipping td, #order_review table .order-total td',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Item - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_cart_item_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal td, #order_review table .shipping td, #order_review table .order-total td',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Item - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_cart_item_padding_vertical',
				'std' => '9',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal td, #order_review table .shipping td, #order_review table .order-total td',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Item - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_shop_table_cart_item_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal td, #order_review table .shipping td, #order_review table .order-total td',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order .payment_methods',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order .payment_methods',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Label - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_label_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Label - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_label_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Label - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_label_padding_horizontal',
				'std' => '6',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment li label',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Box - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_box_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment div.payment_box',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Box - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_box_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment div.payment_box',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Box - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_box_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment div.payment_box',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Box - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_payment_box_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment div.payment_box',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Place Order - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_place_order_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Place Order - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_place_order_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Place Order > Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_place_order_button_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order input[type=submit]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Place Order > Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_t_review_place_order_button_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order input[type=submit]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'tablet', 'lc-woo-integration' ),
			),

			/**
			 * Responsive Phone
			 */

			array(
				'label' => __( 'Responsive Styling', 'lc-woo-integration' ),
				'id' => 'css_res_p',
				'std' => 'disabled',
				'type' => 'select',
				'choices' => array(
					array(
						'label' => __( 'Disabled', 'lc-woo-integration' ),
						'value' => 'disabled',
					),
					array(
						'label' => __( 'Enabled', 'lc-woo-integration' ),
						'value' => 'enabled',
					),
				),
				'section' => 'responsive',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_margin_bottom',
				'std' => '35',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-info',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Coupon - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_coupon_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=text]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Coupon - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_coupon_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=text]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Coupon Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_coupon_button_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Coupon Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_coupon_button_line_height',
				'std' => '18',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon input[type=submit]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Coupon Button - Width', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_coupon_button_width',
				'std' => '30',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon .form-row input[type=submit]',
				'affect_on_change_rule' => 'width',
				'section' => 'responsive',
				'min' => 1,
				'max' => 100,
				'ext' => '%',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Coupon Button - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_coupon_button_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon .form-row input[type=submit]',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Coupon Button - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_coupon_button_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon .form-row input[type=submit]',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Coupon - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_coupon_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.checkout_coupon',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_login_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_login_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login Form - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_login_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login > Label - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_login_label_font_size',
				'std' => '16',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login label',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login > Label - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_login_label_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login label',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login > Label Form - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_login_label_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login label',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login > Input - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_login_input_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=text], form.login input[type=password]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login > Input - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_login_input_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=text], form.login input[type=password]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login > Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_login_button_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=submit]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login > Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_login_button_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login input[type=submit]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login > Button - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_login_button_margin_bottom',
				'std' => '5',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login .form-row input[type=submit]',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login > Button - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_login_button_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login .form-row input[type=submit]',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Info > Login > Button - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_info_login_button_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'form.login .form-row input[type=submit]',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields, .woocommerce-shipping-fields',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields, .woocommerce-shipping-fields',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields, .woocommerce-shipping-fields',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_title_font_size',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields h3, .woocommerce-shipping-fields h3 label',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_title_line_height',
				'std' => '28',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields h3, .woocommerce-shipping-fields h3 label',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Title - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_title_margin_bottom',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields h3, .woocommerce-shipping-fields h3 label',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Label - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_label_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields p label, .woocommerce-shipping-fields p label',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Label - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_label_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields p label, .woocommerce-shipping-fields p label',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Label - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_label_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields p label, .woocommerce-shipping-fields p label',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Label - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_label_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields p label, .woocommerce-shipping-fields p label',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Label - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_label_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields p label, .woocommerce-shipping-fields p label',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Input/Textarea - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_input_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields input, .woocommerce-shipping-fields textarea, .woocommerce-shipping-fields input',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Input/Textarea - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_input_line_height',
				'std' => '19',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields input, .woocommerce-shipping-fields textarea, .woocommerce-shipping-fields input',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Input/Textarea - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_input_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields input, .woocommerce-shipping-fields textarea, .woocommerce-shipping-fields input',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Input/Textarea - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_input_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields input, .woocommerce-shipping-fields textarea, .woocommerce-shipping-fields input',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Input/Textarea - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_input_padding_horizontal',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-billing-fields input, .woocommerce-shipping-fields textarea, .woocommerce-shipping-fields input',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Select - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_select_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lc-product-checkout .select2-container a, .lc-product-checkout select#billing_country, .lc-product-checkout select#billing_state, .lc-product-checkout select#shipping_country, .lc-product-checkout select#shipping_state',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Select - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_select_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lc-product-checkout .select2-container a, .lc-product-checkout select#billing_country, .lc-product-checkout select#billing_state, .lc-product-checkout select#shipping_country, .lc-product-checkout select#shipping_state',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Select - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_select_margin_bottom',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lc-product-checkout .select2-container a, .lc-product-checkout select#billing_country, .lc-product-checkout select#billing_state, .lc-product-checkout select#shipping_country, .lc-product-checkout select#shipping_state',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Select - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_select_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lc-product-checkout .select2-container a, .lc-product-checkout select#billing_country, .lc-product-checkout select#billing_state, .lc-product-checkout select#shipping_country, .lc-product-checkout select#shipping_state',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form > Select - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_select_padding_horizontal',
				'std' => '7',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.lc-product-checkout .select2-container a, .lc-product-checkout select#billing_country, .lc-product-checkout select#billing_state, .lc-product-checkout select#shipping_country, .lc-product-checkout select#shipping_state',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form Message > Error - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_message_error_form_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form Message > Error - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_message_error_line_height',
				'std' => '29',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form Message > Error - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_message_error_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form Message > Error - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_message_error_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Form Message > Error - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_form_message_error_padding_horizontal',
				'std' => '25',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-error',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_title_font_size',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_title_line_height',
				'std' => '28',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Title - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_title_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Title - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_title_padding_horizontal',
				'std' => '20',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => 'h3#order_review_heading',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Titles - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_title_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table th.product-name, #order_review table th.product-total',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Titles - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_title_line_height',
				'std' => '21',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table th.product-name, #order_review table th.product-total',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Titles - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_title_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table th.product-name, #order_review table th.product-total',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Titles - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_title_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table th.product-name, #order_review table th.product-total',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Items - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_items_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item td.product-name, .cart_item td.product-total',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Items - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_items_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item td.product-name, .cart_item td.product-total',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Items - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_items_padding_vertical',
				'std' => '8',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item td.product-name, .cart_item td.product-total',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Items - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_items_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item td.product-name, .cart_item td.product-total',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Variation - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_variation_dt_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name dt, .cart_item .product-name dd',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'tab' => __( 'phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Review > Shop Table > Variation - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_variation_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.cart_item .product-name dt, .cart_item .product-name dd',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'tab' => __( 'phone', 'lc-woo-integration' ),
				'ext' => 'px',
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Title - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_cart_title_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal th, #order_review table .shipping th, #order_review table .order-total th',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Title - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_cart_title_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal th, #order_review table .shipping th, #order_review table .order-total th',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Title - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_cart_title_padding_vertical',
				'std' => '9',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal th, #order_review table .shipping th, #order_review table .order-total th',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Title - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_cart_title_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal th, #order_review table .shipping th, #order_review table .order-total th',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Title - Margin Bottom', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_cart_title_margin_bottom',
				'std' => '40',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table',
				'affect_on_change_rule' => 'margin-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Item - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_cart_item_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal td, #order_review table .shipping td, #order_review table .order-total td',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Item - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_cart_item_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal td, #order_review table .shipping td, #order_review table .order-total td',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Item - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_cart_item_padding_vertical',
				'std' => '9',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal td, #order_review table .shipping td, #order_review table .order-total td',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Shop Table > Cart > Item - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_shop_table_cart_item_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '#order_review table .cart-subtotal td, #order_review table .shipping td, #order_review table .order-total td',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order .payment_methods',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order .payment_methods',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_padding_vertical',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_padding_horizontal',
				'std' => '0',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Label - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_label_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment label',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Label - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_label_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment label',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Label - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_label_padding_horizontal',
				'std' => '6',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment label',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Box - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_box_font_size',
				'std' => '14',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment div.payment_box',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Box - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_box_line_height',
				'std' => '22',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment div.payment_box',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Box - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_box_padding_vertical',
				'std' => '10',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment div.payment_box',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Payment > Box - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_payment_box_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.woocommerce-checkout-review-order #payment div.payment_box',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Place Order - Padding Vertical', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_place_order_padding_vertical',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order',
				'affect_on_change_rule' => 'padding-top,padding-bottom',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Place Order - Padding Horizontal', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_place_order_padding_horizontal',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order',
				'affect_on_change_rule' => 'padding-left,padding-right',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Place Order > Button - Font Size', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_place_order_button_font_size',
				'std' => '15',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order input[type=submit]',
				'affect_on_change_rule' => 'font-size',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),
			array(
				'label' => __( 'Review > Place Order > Button - Line Height', 'lc-woo-integration' ),
				'id' => 'css_res_p_review_place_order_button_line_height',
				'std' => '24',
				'type' => 'slider',
				'refresh_on_change' => false,
				'affect_on_change_el' => '.place-order input[type=submit]',
				'affect_on_change_rule' => 'line-height',
				'section' => 'responsive',
				'ext' => 'px',
				'tab' => __( 'phone', 'lc-woo-integration' ),
			),

		);

		$options = array_merge( $options, $this->shared_options( 'animation_options' ) );
		$options = array_merge( $options, $this->presets_options() );

		return apply_filters( 'dslc_module_options', $options, $this->module_id );
	}

	/**
	 * Output
	 *
	 * @param array $options
	 */
	function output( $options ) {

		$this->module_start( $options );

		global $dslc_active;

		$woo_page = get_option( 'woocommerce_checkout_page_id' );
		$current_page = get_the_ID();

		if ( ( $woo_page === $current_page ) || $dslc_active ) {
			if ( 'dslc_templates' === get_post_type() || $dslc_active ) { ?>
				<div class="lc-product-checkout">
					<div class="woocommerce">
						<div class="woocommerce-info">Returning customer? <a class="showlogin" href="#">Click here to login</a></div>
						<form style="display: none;" class="login" method="post">
							<p>If you have shopped with us before, please enter your details in the boxes below. If you are a new customer please proceed to the Billing &amp; Shipping section.</p>
							<p class="form-row form-row-first">
								<label for="username">Username or email <span class="required">*</span></label>
								<input type="text" id="username" value=" " name="username" class="input-text">
							</p>
							<p class="form-row form-row-last">
								<label for="password">Password <span class="required">*</span></label>
								<input type="password" id="password" value="" name="password" class="input-text">
							</p>
							<div class="clear"></div>
							<p class="form-row">
								<label class="inline" for="rememberme">
								<input type="checkbox" value="forever" id="rememberme" name="rememberme"> Remember me </label>
							</p>
							<p class="lost_password">
								<a href="#">Lost your password?</a>
							</p>
							<div class="clear"></div>
						</form>
						<div class="woocommerce-info">Have a coupon? <a href="#" class="showcoupon">Click here to enter your code</a></div>
						<form class="checkout_coupon" method="post" style="display:none">
							<p class="form-row form-row-first">
								<input type="text" name="coupon_code" class="input-text" placeholder="Coupon code" id="coupon_code" value="">
							</p>
							<p class="form-row form-row-last">
								<input type="submit" class="button" name="apply_coupon" value="Apply Coupon">
							</p>
							<div class="clear"></div>
						</form>
						<form name="checkout" method="post" class="checkout woocommerce-checkout">
							<ul class="woocommerce-error">
								<li><strong>Input</strong> is a required field.</li>
							</ul>
							<div class="col2-set" id="customer_details">
								<div class="col-1">
									<div class="woocommerce-billing-fields">
										<h3>Billing Details</h3>
										<p class="form-row form-row form-row-first validate-required" id="billing_first_name_field">
											<label for="billing_first_name" class="">First Name <abbr class="required" title="required">*</abbr></label>
											<input type="text" class="input-text " name="billing_first_name" id="billing_first_name">
										</p>
										<p class="form-row form-row form-row-last validate-required" id="billing_last_name_field">
											<label for="billing_last_name" class="">Last Name <abbr class="required" title="required">*</abbr></label>
											<input type="text" class="input-text " name="billing_last_name" id="billing_last_name">
										</p>
										<div class="clear"></div>
										<p class="form-row form-row form-row-wide" id="billing_company_field">
											<label for="billing_company" class="">Company Name</label>
											<input type="text" class="input-text " name="billing_company" id="billing_company">
										</p>
										<p class="form-row form-row form-row-first validate-required validate-email" id="billing_email_field">
											<label for="billing_email" class="">Email Address <abbr class="required" title="required">*</abbr></label>
											<input type="email" class="input-text " name="billing_email" id="billing_email">
										</p>
										<p class="form-row form-row form-row-last validate-required validate-phone" id="billing_phone_field">
											<label for="billing_phone" class="">Phone <abbr class="required" title="required">*</abbr></label>
											<input type="tel" class="input-text " name="billing_phone" id="billing_phone">
										</p>
										<div class="clear"></div>
										<p class="form-row form-row form-row-wide address-field update_totals_on_change validate-required woocommerce-validated" id="billing_country_field">
											<label for="billing_country" class="">Country <abbr class="required" title="required">*</abbr></label>
											<select id="billing_country" title="Country *">
												<option value="" selected="selected">Select a country…</option>
												<option value="AR">Argentina</option>
												<option value="BR">Brazil</option>
												<option value="BG">Bulgaria</option>
												<option value="CO">Colombia</option>
												<option value="FI">Finland</option>
												<option value="FR">France</option>
												<option value="IT">Italy</option>
												<option value="GB">United Kingdom (UK)</option>
												<option value="US">United States (US)</option>
											</select>
										</p>
										<p class="form-row form-row form-row-wide address-field validate-required" id="billing_address_1_field">
											<label for="billing_address_1" class="">Address <abbr class="required" title="required">*</abbr></label>
											<input type="text" class="input-text " name="billing_address_1" id="billing_address_1" placeholder="Street address">
										</p>
										<p class="form-row form-row form-row-wide address-field" id="billing_address_2_field">
											<input type="text" class="input-text " name="billing_address_2" id="billing_address_2" placeholder="Apartment, suite, unit etc. (optional)">
										</p>
										<p class="form-row form-row form-row-wide address-field validate-required" id="billing_city_field">
											<label for="billing_city" class="">Town / City <abbr class="required" title="required">*</abbr></label>
											<input type="text" class="input-text " name="billing_city" id="billing_city" placeholder="Town / City">
										</p>
										<p class="form-row form-row form-row-first address-field validate-state validate-required" id="billing_state_field">
											<label for="billing_state" class="">State / County <abbr class="required" title="required">*</abbr></label>
											<input type="text" class="input-text" name="billing_state" id="billing_state">
										</p>
										<p class="form-row form-row form-row-last address-field validate-postcode validate-required" id="billing_postcode_field">
											<label for="billing_postcode" class="">Postcode / Zip <abbr class="required" title="required">*</abbr></label>
											<input type="text" class="input-text " name="billing_postcode" id="billing_postcode" placeholder="Postcode / Zip" value=" ">
										</p>
										<div class="clear"></div>
										<p class="form-row form-row-wide create-account">
											<input type="checkbox" value="1" name="f_show" onclick="showMe('create-account')" id="createaccount" class="input-checkbox">
											<label class="checkbox">Create an account?</label>
										</p>
										<div id="create-account" style="display:none">
											<p>Create an account by entering the information below. If you are a returning customer please login at the top of the page.</p>
											<p id="account_password_field" class="form-row form-row validate-required">
												<label class="" for="account_password">Account password <abbr title="required" class="required">*</abbr></label>
												<input type="password" value="" placeholder="Password" id="account_password" name="account_password" class="input-text ">
											</p>
											<div class="clear"></div>
										</div>
									</div>
								</div>
								<div class="col-2">
									<div class="woocommerce-shipping-fields">
										<h3>
											<label for="ship-to-different-address-checkbox" class="checkbox">Ship to a different address?</label>
											<input  type="checkbox" name="f_show" onclick="showMe('shipping_address')" value="1">
										</h3>
										<div id="shipping_address" class="shipping_address" style="display:none">
											<p class="form-row form-row form-row-first validate-required" id="shipping_first_name_field">
												<label for="shipping_first_name" class="">First Name <abbr class="required" title="required">*</abbr></label>
												<input type="text" class="input-text " name="shipping_first_name" id="shipping_first_name">
											</p>
											<p class="form-row form-row form-row-last validate-required" id="shipping_last_name_field">
												<label for="shipping_last_name" class="">Last Name <abbr class="required" title="required">*</abbr></label>
												<input type="text" class="input-text " name="shipping_last_name" id="shipping_last_name">
											</p>
											<div class="clear"></div>
											<p class="form-row form-row form-row-wide" id="shipping_company_field">
												<label for="shipping_company" class="">Company Name</label>
												<input type="text" class="input-text " name="shipping_company" id="shipping_company">
											</p>
											<p class="form-row form-row form-row-wide address-field update_totals_on_change validate-required woocommerce-validated" id="shipping_country_field">
												<label for="shipping_country" class="">Country <abbr class="required" title="required">*</abbr></label>
												<select id="shipping_country" title="Country *">
													<option value="" selected="selected">Select a country…</option>
													<option value="AR">Argentina</option>
													<option value="BR">Brazil</option>
													<option value="BG">Bulgaria</option>
													<option value="CO">Colombia</option>
													<option value="FI">Finland</option>
													<option value="FR">France</option>
													<option value="IT">Italy</option>
													<option value="GB">United Kingdom (UK)</option>
													<option value="US">United States (US)</option>
												</select>
											</p>
											<p class="form-row form-row form-row-wide address-field validate-required" id="shipping_address_1_field">
												<label for="shipping_address_1" class="">Address <abbr class="required" title="required">*</abbr></label>
												<input type="text" class="input-text " name="shipping_address_1" id="shipping_address_1" placeholder="Street address">
											</p>
											<p class="form-row form-row form-row-wide address-field" id="shipping_address_2_field">
												<input type="text" class="input-text " name="shipping_address_2" id="shipping_address_2" placeholder="Apartment, suite, unit etc. (optional)">
											</p>
											<p class="form-row form-row form-row-wide address-field validate-required" id="shipping_city_field">
												<label for="shipping_city" class="">Town / City <abbr class="required" title="required">*</abbr></label>
												<input type="text" class="input-text " name="shipping_city" id="shipping_city" placeholder="Town / City">
											</p>
											<p class="form-row form-row form-row-first address-field validate-state validate-required" id="shipping_state_field">
												<label for="shipping_state" class="">State / County <abbr class="required" title="required">*</abbr></label>
												<input type="text" class="input-text" name="shipping_state" id="shipping_state">
											</p>
											<p class="form-row form-row form-row-last address-field validate-postcode validate-required" id="shipping_postcode_field">
												<label for="shipping_postcode" class="">Postcode / Zip <abbr class="required" title="required">*</abbr></label>
												<input type="text" class="input-text " name="shipping_postcode" id="shipping_postcode" placeholder="Postcode / Zip">
											</p>
											<div class="clear"></div>
										</div>
										<p class="form-row form-row notes" id="order_comments_field">
											<label for="order_comments" class="">Order Notes</label>
											<textarea name="order_comments" class="input-text " id="order_comments" placeholder="Notes about your order, e.g. special notes for delivery." rows="2" cols="5"></textarea>
										</p>
									</div>
								</div>
							</div>
							<h3 id="order_review_heading">Your order</h3>
							<div id="order_review" class="woocommerce-checkout-review-order">
								<table class="shop_table">
									<thead>
										<tr>
											<th class="product-name">Product</th>
											<th class="product-total">Total</th>
										</tr>
									</thead>
									<tbody>
										<tr class="cart_item">
											<td class="product-name"> Ship Your Idea&nbsp;	<strong class="product-quantity">× 1</strong>
												<dl class="variation">
													<dt class="variation-color">color:</dt>
													<dd class="variation-color"><p>Black</p></dd>
												</dl>
											</td>
											<td class="product-total"><span class="amount">£35.00</span></td>
										</tr>
									</tbody>
									<tfoot>
										<tr class="cart-subtotal">
											<th>Subtotal</th>
											<td><span class="amount">£35.00</span></td>
										</tr>
										<tr class="shipping">
											<th>Shipping</th>
											<td>Free Shipping</td>
										</tr>
										<tr class="order-total">
											<th>Total</th>
											<td><strong><span class="amount">£35.00</span></strong> </td>
										</tr>
									</tfoot>
								</table>
								<div id="payment">
									<ul class="payment_methods methods">
										<li class="payment_method_cheque">
											<input id="payment_method_cheque" type="radio" class="input-radio" name="payment_method" value="cheque" checked="checked">
											<label for="payment_method_cheque"> Cheque Payment </label>
											<div class="payment_box payment_method_cheque">
												<p>Please send your cheque to Store Name, Store Street, Store Town, Store State / County, Store Postcode.</p>
											</div>
										</li>
										<li class="payment_method_paypal">
											<input id="payment_method_paypal" type="radio" class="input-radio" name="payment_method" value="paypal">
											<label for="payment_method_paypal">
												PayPal <img src="https://www.paypalobjects.com/webstatic/mktg/Logo/AM_mc_vs_ms_ae_UK.png" alt="PayPal Acceptance Mark"><a href="#" class="about_paypal">What is PayPal?</a>
											</label>
											<div class="payment_box payment_method_paypal">
												<p>Pay via PayPal; you can pay with your credit card if you don’t have a PayPal account.</p>
											</div>
										</li>
									</ul>
									<div class="form-row place-order">
										<input type="submit" class="button alt" name="woocommerce_checkout_place_order" id="place_order" value="Place order" data-value="Place order">
									</div>
								</div>
							</div>
						</form>
					</div>
				</div>
				<style type="text/css">
					input[type="radio"]+label+div{ display: none; }
					input[type="radio"]:checked+label+div{ display: block; }
				</style>
				<script type="text/javascript">
					function showMe (box) {
					    var chboxs = document.getElementsByName("f_show");
					    var vis = "none";
					    for(var i=0;i<chboxs.length;i++) {
					        if(chboxs[i].checked){
					         vis = "block";
					            break;
					        }
					    }
					    document.getElementById(box).style.display = vis;
					}
				</script>
			<?php
			} else { ?>
				<div class='lc-product-checkout'>
					<?php echo do_shortcode( '[woocommerce_checkout]' ); ?>
				</div>
		<?php }
		} else { ?>
			<div class="dslc-notification dslc-red">
				<?php esc_html_e( 'This module will work when you choose the Checkout page in WooCommerce. ( WooCommerce -> Settings -> Checkout -> Checkout Page )', 'lc-woo-integration' ); ?>
			</div>
		<?php }

		$this->module_end( $options );
	}
}

add_action('dslc_hook_register_modules',
	create_function( '', 'return dslc_register_module( "LCWoo_Checkout" );' )
);
